MSG_HASH(
	MSG_COMPILER,
	"Compilador"
	)
MSG_HASH(
	MSG_UNKNOWN_COMPILER,
	"Compilador Desconocido"
	)
MSG_HASH(
	MSG_DEVICE_DISCONNECTED_FROM_PORT,
	"Dispositivo desconectado del puerto"
	)
MSG_HASH(
	MSG_UNKNOWN_NETPLAY_COMMAND_RECEIVED,
	"Recibido un comando de juego en red desconocido"
	)
MSG_HASH(
	MSG_FILE_ALREADY_EXISTS_SAVING_TO_BACKUP_BUFFER,
	"El archivo ya existe. Guardándolo en el búfer de respaldo"
	)
MSG_HASH(
	MSG_GOT_CONNECTION_FROM,
	"Conexión obtenida de: \"%s\""
	)
MSG_HASH(
	MSG_GOT_CONNECTION_FROM_NAME,
	"Conexión obtenida de: \"%s (%s)\""
	)
MSG_HASH(
	MSG_PUBLIC_ADDRESS,
	"Dirección pública"
	)
MSG_HASH(
	MSG_NO_ARGUMENTS_SUPPLIED_AND_NO_MENU_BUILTIN,
	"No se pasaron argumentos y no hay menú integrado, Mostrando ayuda.."
	)
MSG_HASH(
	MSG_SETTING_DISK_IN_TRAY,
	"Poniendo disco en bandeja"
	)
MSG_HASH(
	MSG_WAITING_FOR_CLIENT,
	"Esperando al cliente .."
	)
MSG_HASH(
	MSG_NETPLAY_YOU_HAVE_LEFT_THE_GAME,
	"As dejado el juego"
	)
MSG_HASH(
	MSG_NETPLAY_YOU_HAVE_JOINED_AS_PLAYER_N,
	"Unido como jugador %u"
	)
MSG_HASH(
	MSG_NETPLAY_YOU_HAVE_JOINED_WITH_INPUT_DEVICES_S,
	"Se ha unido con el dispositivo de entrada %.*s"
	)
MSG_HASH(
	MSG_NETPLAY_PLAYER_S_LEFT,
	"Jugador %.*s dejó el juego"
	)
MSG_HASH(
	MSG_NETPLAY_S_HAS_JOINED_AS_PLAYER_N,
	"%.*s se ha unido como jugador %u"
	)
MSG_HASH(
	MSG_NETPLAY_S_HAS_JOINED_WITH_INPUT_DEVICES_S,
	"%.*s se ha unido con los dispositivos de entrada %.*s"
	)
MSG_HASH(
	MSG_NETPLAY_NOT_RETROARCH,
	"Una conexión de netplay falló, probablemente no este usando RetroArch o esté usando una versión antigua de RetroArch"
	)
MSG_HASH(
	MSG_NETPLAY_OUT_OF_DATE,
	"El par de netplay esta usando una versión antigua de RetroArch. No se puede conectar"
	)
MSG_HASH(
	MSG_NETPLAY_DIFFERENT_VERSIONS,
	"ADVERTENCIA: Un par de netplay esta usando una versión diferente de Retroarch. Si ocurren problemas, use la misma versión"
	)
MSG_HASH(
	MSG_NETPLAY_DIFFERENT_CORES,
	"Un par de netplay esta usando una versión diferente del núcleo. No se puede conectar"
	)
MSG_HASH(
	MSG_NETPLAY_DIFFERENT_CORE_VERSIONS,
	"ADVERTENCIA: Un par de netplay está ejecutando una versión diferente del núcleo. Si ocurren problemas, use la misma versión"
	)
MSG_HASH(
	MSG_NETPLAY_ENDIAN_DEPENDENT,
	"Este núcleo no soporta juego en red entre diferentes arquitecturas de sistemas"
	)
MSG_HASH(
	MSG_NETPLAY_PLATFORM_DEPENDENT,
	"Este núcleo no soporta juego en red entre diferentes sistemas"
	)
MSG_HASH(
	MSG_NETPLAY_ENTER_PASSWORD,
	"Introducir la contraseña del servidor de juego en red:"
	)
MSG_HASH(
	MSG_NETPLAY_INCORRECT_PASSWORD,
	"Contraseña incorrecta"
	)
MSG_HASH(
	MSG_NETPLAY_SERVER_NAMED_HANGUP,
	"\"%s\" se ha desconectado"
	)
MSG_HASH(
	MSG_NETPLAY_SERVER_HANGUP,
	"Un cliente de juego en red se ha desconectado"
	)
MSG_HASH(
	MSG_NETPLAY_CLIENT_HANGUP,
	"Juego en red desconectado"
	)
MSG_HASH(
	MSG_NETPLAY_CANNOT_PLAY_UNPRIVILEGED,
	"No tienes permiso para jugar"
	)
MSG_HASH(
	MSG_NETPLAY_CANNOT_PLAY_NO_SLOTS,
	"No hay lugar disponible"
	)
MSG_HASH(
	MSG_NETPLAY_CANNOT_PLAY_NOT_AVAILABLE,
	"El dispositivo de entrada pedido no esta disponible"
	)
MSG_HASH(
	MSG_NETPLAY_CANNOT_PLAY,
	"No se puede cambiar al modo juego"
	)
MSG_HASH(
	MSG_NETPLAY_PEER_PAUSED,
	"Cliente de juego en red \"%s\" pausado"
	)
MSG_HASH(
	MSG_NETPLAY_CHANGED_NICK,
	"Tu apodo cambió a \"%s\""
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_SHARED_CONTEXT,
	"Dar a los núcleos renderizados por hardware un contexto privado. Evita tener que asumir cambios en el estado del hardware entre cuadros"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_MENU_SETTINGS,
	"Ajusta la apariencia del menú"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_HARD_SYNC,
	"Fuerza la Sincronía de CPU y GPU. Reduce la latencia a costa del rendimiento"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_THREADED,
	"Mejora el rendimiento a costa de la latencia y mas video stuttering. Usar solo si no puede obtener máxima velocidad de otra manera"
	)
MSG_HASH(
	MSG_AUDIO_VOLUME,
	"Volumen de Audio"
	)
MSG_HASH(
	MSG_AUTODETECT,
	"Auto-detectar"
	)
MSG_HASH(
	MSG_AUTOLOADING_SAVESTATE_FROM,
	"Auto-cargar guardado rápido desde"
	)
MSG_HASH(
	MSG_CAPABILITIES,
	"Capacidades"
	)
MSG_HASH(
	MSG_CONNECTING_TO_NETPLAY_HOST,
	"Conectando al servidor de juego en red"
	)
MSG_HASH(
	MSG_CONNECTING_TO_PORT,
	"Conectando al puerto"
	)
MSG_HASH(
	MSG_CONNECTION_SLOT,
	"Lugar de conexión"
	)
MSG_HASH(
	MSG_SORRY_UNIMPLEMENTED_CORES_DONT_DEMAND_CONTENT_NETPLAY,
	"Lo sentimos, no implementado: los núcleos que no requieren contenido no pueden participar en juego en red"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_ACCOUNTS_CHEEVOS_PASSWORD,
	"Contraseña"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_ACCOUNTS_CHEEVOS_SETTINGS,
	"Cuenta de logros"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_ACCOUNTS_CHEEVOS_USERNAME,
	"Nombre de usuario"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_ACCOUNTS_LIST,
	"Cuentas"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_ACCOUNTS_LIST_END,
	"Fin de la lista"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_ACCOUNTS_RETRO_ACHIEVEMENTS,
	"RetroAchievements"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_ACHIEVEMENT_LIST,
	"Lista de logros"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_ACHIEVEMENT_LIST_HARDCORE,
	"Lista de logros (Hardcore)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_ADD_CONTENT_LIST,
	"Escanear Contenido"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CONFIGURATIONS_LIST,
	"Configuraciones"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_ADD_TAB,
	"Importar contenido"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_TAB,
	"Salas de juego en red"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_ASK_ARCHIVE,
	"Preguntar"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_ASSETS_DIRECTORY,
	"Recursos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_AUDIO_BLOCK_FRAMES,
	"Bloquear frames"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_AUDIO_DEVICE,
	"Dispositivo de audio"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_AUDIO_DRIVER,
	"Audio driver"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_AUDIO_DSP_PLUGIN,
	"Audio DSP plugin"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_AUDIO_ENABLE,
	"Activar audio"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_AUDIO_FILTER_DIR,
	"Filtro de audio"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_TURBO_DEADZONE_LIST,
	"Turbo/Zona Muerta"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_AUDIO_LATENCY,
	"Latencia de audio (ms)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_AUDIO_MAX_TIMING_SKEW,
	"Variación máxima de sincronía de audio"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_AUDIO_MUTE,
	"Silenciar audio"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_AUDIO_OUTPUT_RATE,
	"Frecuencia de muestreo de audio (Hz)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_AUDIO_RATE_CONTROL_DELTA,
	"Control de frecuencia dinámico"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_AUDIO_RESAMPLER_DRIVER,
	"Controlador de muestreo de audio"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_AUDIO_SETTINGS,
	"Audio"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_AUDIO_SYNC,
	"Sincronía de audio"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_AUDIO_VOLUME,
	"Volumen de Audio (dB)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_AUDIO_WASAPI_EXCLUSIVE_MODE,
	"WASAPI Mode Exclusivo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_AUDIO_WASAPI_FLOAT_FORMAT,
	"WASAPI Formato de coma flotante"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_AUDIO_WASAPI_SH_BUFFER_LENGTH,
	"WASAPI Tamaño del búfer compartido"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_AUTOSAVE_INTERVAL,
	"Intervalo de auto-guardado SaveRAM"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_AUTO_OVERRIDES_ENABLE,
	"Cargar autom. archivos de anulación"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_AUTO_REMAPS_ENABLE,
	"Cargar autom. archivos de re-mapeo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_AUTO_SHADERS_ENABLE,
	"Cargar Shaders automáticamente"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_BACK,
	"Atrás"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_CONFIRM,
	"Confirmar"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_INFO,
	"Información"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_QUIT,
	"Salir"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_SCROLL_DOWN,
	"Desplazar hacia abajo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_SCROLL_UP,
	"Desplazar hacia arriba"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_START,
	"Iniciar"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_TOGGLE_KEYBOARD,
	"Mostrar teclado"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_TOGGLE_MENU,
	"Mostrar menú"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS,
	"Controles básicos del menú"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_CONFIRM,
	"Confirmar"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_INFO,
	"Información"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_QUIT,
	"Salir"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_SCROLL_UP,
	"Desplazar hacia arriba"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_START,
	"Valores predeterminados"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_TOGGLE_KEYBOARD,
	"Mostrar teclado"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_TOGGLE_MENU,
	"Mostrar menú"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_BLOCK_SRAM_OVERWRITE,
	"No sobrescribir SaveRAM al cargar un guardado rápido"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_BLUETOOTH_ENABLE,
	"Activar Bluetooth"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_BUILDBOT_ASSETS_URL,
	"URL de recursos del Buildbot"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CACHE_DIRECTORY,
	"Caché"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CAMERA_ALLOW,
	"Permitir cámara"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CAMERA_DRIVER,
	"Controlador de cámara"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CHEAT,
	"Truco"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CHEAT_APPLY_CHANGES,
	"Aplicar trucos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CHEAT_DATABASE_PATH,
	"Archivo de trucos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CHEAT_FILE,
	"Archivo de trucos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CHEAT_FILE_LOAD,
	"Cargar archivo de trucos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CHEAT_FILE_SAVE_AS,
	"Guardar archivo de trucos como"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CHEAT_NUM_PASSES,
	"Pasadas de trucos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CHEEVOS_DESCRIPTION,
	"Descripción"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CHEEVOS_HARDCORE_MODE_ENABLE,
	"Logros en modo Hardcore"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CHEEVOS_LEADERBOARDS_ENABLE,
	"Tablas de clasificación"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CHEEVOS_BADGES_ENABLE,
	"Insignias de logros"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CHEEVOS_LOCKED_ACHIEVEMENTS,
	"Logros bloqueados:"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CHEEVOS_LOCKED_ENTRY,
	"Bloqueado"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CHEEVOS_SETTINGS,
	"RetroAchievements"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CHEEVOS_TEST_UNOFFICIAL,
	"Probar logros No oficiales"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CHEEVOS_UNLOCKED_ACHIEVEMENTS,
	"Logros desbloqueados:"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CHEEVOS_UNLOCKED_ENTRY,
	"Desbloqueado"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CHEEVOS_UNLOCKED_ENTRY_HARDCORE,
	"Hardcore"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CHEEVOS_VERBOSE_ENABLE,
	"Logros modo informativo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CLOSE_CONTENT,
	"Cerrar"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CONFIG,
	"Config"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CONFIGURATIONS,
	"Cargar configuración"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CONFIGURATION_SETTINGS,
	"Configuración"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CONFIG_SAVE_ON_EXIT,
	"Guardar configuración al salir"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CONTENT_COLLECTION_LIST,
	"Colecciones"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CONTENT_DATABASE_DIRECTORY,
	"Base de datos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CONTENT_DIR,
	"Contenido"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CONTENT_HISTORY_SIZE,
	"Tamaño del historial"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_PLAYLIST_ENTRY_REMOVE,
	"Permitir quitar entradas"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CONTENT_SETTINGS,
	"Menú rápido"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CORE_ASSETS_DIR,
	"Descargas"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CORE_ASSETS_DIRECTORY,
	"Descargas"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CORE_CHEAT_OPTIONS,
	"Trucos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CORE_COUNTERS,
	"Contadores de núcleo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CORE_ENABLE,
	"Mostrar nombre del núcleo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CORE_INFORMATION,
	"Información del núcleo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CORE_INFO_AUTHORS,
	"Autores"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CORE_INFO_CATEGORIES,
	"Categorías"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CORE_INFO_CORE_LABEL,
	"Etiqueta del núcleo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CORE_INFO_CORE_NAME,
	"Nombre del núcleo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CORE_INFO_FIRMWARE,
	"Firmware(s)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CORE_INFO_LICENSES,
	"Licencia(s)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CORE_INFO_PERMISSIONS,
	"Permisos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CORE_INFO_SUPPORTED_EXTENSIONS,
	"Extensiones compatibles"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CORE_INFO_SYSTEM_MANUFACTURER,
	"Fabricante del sistema"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CORE_INFO_SYSTEM_NAME,
	"Nombre del sistema"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CORE_INPUT_REMAPPING_OPTIONS,
	"Controles"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CORE_LIST,
	"Cargar núcleo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CORE_OPTIONS,
	"Opciones"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CORE_SETTINGS,
	"Núcleo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CORE_SET_SUPPORTS_NO_CONTENT_ENABLE,
	"Iniciar un núcleo automáticamente"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CORE_UPDATER_AUTO_EXTRACT_ARCHIVE,
	"Extraer automáticamente el archivo descargado"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CORE_UPDATER_BUILDBOT_URL,
	"URL de núcleos de Buildbot"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CORE_UPDATER_LIST,
	"Actualizador de núcleos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CORE_UPDATER_SETTINGS,
	"Actualizador"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CPU_ARCHITECTURE,
	"Arquitectura de CPU:"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CPU_CORES,
	"Núcleos de CPU:"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CURSOR_DIRECTORY,
	"Cursor"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CURSOR_MANAGER,
	"Gestor de cursores"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CUSTOM_RATIO,
	"Relación personalizada"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DATABASE_MANAGER,
	"Gestor de bases de datos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DATABASE_SELECTION,
	"Seleccionar bases de datos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DELETE_ENTRY,
	"Quitar"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_FAVORITES,
	"Favoritos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DIRECTORY_CONTENT,
	"<Carpeta de contenido>"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DIRECTORY_DEFAULT,
	"<Predeterminada>"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DIRECTORY_NONE,
	"<Ninguna>"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DIRECTORY_NOT_FOUND,
	"No se ha encontrado la carpeta"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DIRECTORY_SETTINGS,
	"Carpetas"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DISK_CYCLE_TRAY_STATUS,
	"Estado de la bandeja de discos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DISK_IMAGE_APPEND,
	"Asignar imagen de disco"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DISK_INDEX,
	"Índice de disco"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DISK_OPTIONS,
	"Control de disco"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DONT_CARE,
	"No importa"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DOWNLOADED_FILE_DETECT_CORE_LIST,
	"Descargas"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DOWNLOAD_CORE,
	"Descargar núcleo.."
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DOWNLOAD_CORE_CONTENT,
	"Descargador de contenido"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DPI_OVERRIDE_ENABLE,
	"Forzar DPI"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DPI_OVERRIDE_VALUE,
	"Anular DPI"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DRIVER_SETTINGS,
	"Controladores"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DUMMY_ON_CORE_SHUTDOWN,
	"Cargar vacío al cerrar núcleo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CHECK_FOR_MISSING_FIRMWARE,
	"Chequear si falta Firmware antes de cargar"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DYNAMIC_WALLPAPER,
	"Fondo de pantalla dinámico"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DYNAMIC_WALLPAPERS_DIRECTORY,
	"Fondos de pantalla dinámicos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CHEEVOS_ENABLE,
	"Activar logros"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_ENTRY_HOVER_COLOR,
	"Color de resaltado del menú"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_ENTRY_NORMAL_COLOR,
	"Color normal del menú"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_FALSE,
	"Desactivado"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_FASTFORWARD_RATIO,
	"Velocidad máxima de ejecución"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_FAVORITES_TAB,
	"Favoritos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_FPS_SHOW,
	"Mostrar FPS"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_FRAME_THROTTLE_ENABLE,
	"Limitar velocidad máxima de ejecución"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_FRAME_THROTTLE_SETTINGS,
	"Velocidad de frames"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_FRONTEND_COUNTERS,
	"Contadores de la interfaz"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_GAME_SPECIFIC_OPTIONS,
	"Usar opciones de núcleo para cada juego si existen"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_GAME_SPECIFIC_OPTIONS_CREATE,
	"Crear archivo de opciones del juego"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_GAME_SPECIFIC_OPTIONS_IN_USE,
	"Archivo de opciones del juego"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_HELP,
	"Ayuda"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_HELP_AUDIO_VIDEO_TROUBLESHOOTING,
	"Solucionar problemas de Audio/Video"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_HELP_CHANGE_VIRTUAL_GAMEPAD,
	"Cambiar el mando virtual superpuesto"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_HELP_CONTROLS,
	"Controles básicos del menú"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_HELP_LIST,
	"Ayuda"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_HELP_LOADING_CONTENT,
	"Cargando contenido"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_HELP_SCANNING_CONTENT,
	"Buscando contenido"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_HELP_WHAT_IS_A_CORE,
	"¿Qué es un núcleo?"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_HISTORY_LIST_ENABLE,
	"Activar Historial"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_HISTORY_TAB,
	"Historial"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_HORIZONTAL_MENU,
	"Menú Horizontal"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_IMAGES_TAB,
	"Imágenes"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INFORMATION,
	"Información"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INFORMATION_LIST,
	"Información"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_ADC_TYPE,
	"Tipo de analógico a digital"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_ALL_USERS_CONTROL_MENU,
	"Todos controlan el menú"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_X,
	"Analógico izq. X"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_X_MINUS,
	"Analógico izq. X- (IZQUIERDA)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_X_PLUS,
	"Analógico izq. X+ (DERECHA)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_Y,
	"Analógico izq. Y"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_Y_MINUS,
	"Analógico izq. Y- (ARRIBA)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_Y_PLUS,
	"Analógico izq. Y+ (ABAJO)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_X,
	"Analógico der. X"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_X_MINUS,
	"Analógico der. X- (IZQUIERDA)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_X_PLUS,
	"Analógico der. X+ (DERECHA)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_Y,
	"Analógico der. Y"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_Y_MINUS,
	"Analógico der. Y- (ARRIBA)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_Y_PLUS,
	"Analógico der. Y+ (ABAJO)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_TRIGGER,
	"Arma: Gatillo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_RELOAD,
	"Arma: Recargar"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_AUX_A,
	"Arma: Aux A"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_AUX_B,
	"Arma: Aux B"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_AUX_C,
	"Arma: Aux C"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_START,
	"Arma: Start"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_SELECT,
	"Arma: Select"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_DPAD_UP,
	"Arma: D-pad ARRIBA"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_DPAD_DOWN,
	"Arma: D-pad ABAJO"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_DPAD_LEFT,
	"Arma: D-pad IZQUIERDA"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_DPAD_RIGHT,
	"Arma: D-pad DERECHA"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_AUTODETECT_ENABLE,
	"Activar Auto-configuración"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_AXIS_THRESHOLD,
	"Zona muerta analógica"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MENU_INPUT_SWAP_OK_CANCEL,
	"Menú: cambiar OK y Cancelar"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_BIND_ALL,
	"Asignar todo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_BIND_DEFAULT_ALL,
	"Asignar valores por defecto"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_BIND_TIMEOUT,
	"Tiempo limite para asignar"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_DESCRIPTOR_HIDE_UNBOUND,
	"Ocultar descripciones de entrada sin asignar de los núcleo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_DESCRIPTOR_LABEL_SHOW,
	"Mostrar etiquetas de descripción de entrada"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_DEVICE_INDEX,
	"Indice de dispositivo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_DEVICE_TYPE,
	"Tipo de dispositivo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_INDEX,
	"Indice de ratón"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_DRIVER,
	"Controlador de entrada"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_DUTY_CYCLE,
	"Ciclo de trabajo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_HOTKEY_BINDS,
	"Asignar Hotkeys"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_ICADE_ENABLE,
	"Activar mapeo de Teclado-Mando"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_A,
	"Botón A (DERECHA)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_B,
	"Botón B (ABAJO)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_DOWN,
	"D-pad ABAJO"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_L2,
	"Botón L2 (LT)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_L3,
	"Botón L3 (Pulsar analógico IZQ.)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_L,
	"Botón L1 (LB)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_LEFT,
	"D-pad IZQUIERDA"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_R2,
	"Botón R2 (RT)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_R3,
	"Botón R3 (Pulsar analógico DER.)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_R,
	"Botón R1 (RB)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_RIGHT,
	"D-pad DERECHA"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_SELECT,
	"Botón Select"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_START,
	"Botón Start"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_UP,
	"D-pad ARRIBA"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_X,
	"Botón X (ARRIBA)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_Y,
	"Botón Y (IZQUIERDA)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_KEY,
	"(Tecla: %s)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_LEFT,
	"Ratón 1"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_RIGHT,
	"Ratón 2"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_MIDDLE,
	"Ratón 3"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_BUTTON4,
	"Ratón 4"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_BUTTON5,
	"Ratón 5"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_WHEEL_UP,
	"Rueda ARRIBA"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_WHEEL_DOWN,
	"Rueda ABAJO"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_HORIZ_WHEEL_UP,
	"Rueda IZQUIERDA"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_HORIZ_WHEEL_DOWN,
	"Rueda DERECHA"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_KEYBOARD_GAMEPAD_MAPPING_TYPE,
	"Tipo de mapeo Teclado-Mando"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_MAX_USERS,
	"Máximo de usuarios"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_MENU_ENUM_TOGGLE_GAMEPAD_COMBO,
	"Combinación para mostrar el menú"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_META_CHEAT_INDEX_MINUS,
	"Indice de trucos -"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_META_CHEAT_INDEX_PLUS,
	"Indice de trucos +"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_META_CHEAT_TOGGLE,
	"Activar truco"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_META_DISK_EJECT_TOGGLE,
	"Expulsar disco"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_META_DISK_NEXT,
	"Siguiente disco"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_META_DISK_PREV,
	"Disco previo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_META_ENABLE_HOTKEY,
	"Activar hotkeys"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_META_FAST_FORWARD_HOLD_KEY,
	"Mantener para avance rápido"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_META_FAST_FORWARD_KEY,
	"Avance rápido"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_META_FRAMEADVANCE,
	"Avanzar frame"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_META_FULLSCREEN_TOGGLE_KEY,
	"Pantalla completa"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_META_GRAB_MOUSE_TOGGLE,
	"Capturar ratón"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_META_GAME_FOCUS_TOGGLE,
	"Game focus (desactivar hotkeys)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_META_LOAD_STATE_KEY,
	"Cargar estado"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_META_MENU_TOGGLE,
	"Mostrar menú"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_META_MOVIE_RECORD_TOGGLE,
	"Grabar video"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_META_MUTE,
	"Silenciar audio"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_META_NETPLAY_GAME_WATCH,
	"Juego en red: cambiar modo juego/espectador"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_META_OSK,
	"Mostrar teclado en pantalla"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_META_OVERLAY_NEXT,
	"Siguiente Overlay"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_META_PAUSE_TOGGLE,
	"Pausar"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_META_QUIT_KEY,
	"Cerrar RetroArch"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_META_RESET,
	"Resetear juego"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_META_REWIND,
	"Rebobinar"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_META_SAVE_STATE_KEY,
	"Guardar estado"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_META_SCREENSHOT,
	"Captura de pantalla"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_META_SHADER_NEXT,
	"Siguiente shader"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_META_SHADER_PREV,
	"Shader previo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_META_SLOWMOTION_HOLD_KEY,
	"Cámara lenta"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_META_STATE_SLOT_MINUS,
	"Ranura de guardado -"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_META_STATE_SLOT_PLUS,
	"Ranura de guardado +"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_META_VOLUME_DOWN,
	"Volumen -"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_META_VOLUME_UP,
	"Volumen +"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_OVERLAY_ENABLE,
	"Mostrar Overlay"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_OVERLAY_HIDE_IN_MENU,
	"Ocultar Overlay en el menú"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_OVERLAY_SHOW_PHYSICAL_INPUTS,
	"Mostrar entradas en Overlay"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_OVERLAY_SHOW_PHYSICAL_INPUTS_PORT,
	"Puerto de escucha para entradas"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_POLL_TYPE_BEHAVIOR,
	"Comportamiento del sondeo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_POLL_TYPE_BEHAVIOR_EARLY,
	"Temprano"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_POLL_TYPE_BEHAVIOR_LATE,
	"Tarde"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_POLL_TYPE_BEHAVIOR_NORMAL,
	"Normal"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_PREFER_FRONT_TOUCH,
	"Preferir táctil frontal"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_REMAPPING_DIRECTORY,
	"Reasignación de entrada"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_REMAP_BINDS_ENABLE,
	"Permitir reasignar controles"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_SAVE_AUTOCONFIG,
	"Guardar Auto-configuración"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_SETTINGS,
	"Controles"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_SMALL_KEYBOARD_ENABLE,
	"Activar teclado pequeño"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_TOUCH_ENABLE,
	"Activar táctil"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_TURBO_ENABLE,
	"Activar turbo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_TURBO_PERIOD,
	"Periodo del turbo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_USER_BINDS,
	"Controles del usuario %u"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INTERNAL_STORAGE_STATUS,
	"Estado del almacenamiento interno"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_JOYPAD_AUTOCONFIG_DIR,
	"Auto-configuración de controles"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_JOYPAD_DRIVER,
	"Controlador de mando"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_LAKKA_SERVICES,
	"Servicios"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_LANG_CHINESE_SIMPLIFIED,
	"Chino (Simplificado)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_LANG_CHINESE_TRADITIONAL,
	"Chino (Tradicional)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_LANG_DUTCH,
	"Holandés"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_LANG_ENGLISH,
	"Ingles"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_LANG_ESPERANTO,
	"Esperanto"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_LANG_FRENCH,
	"Francés"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_LANG_GERMAN,
	"Alemán"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_LANG_ITALIAN,
	"Italiano"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_LANG_JAPANESE,
	"Japones"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_LANG_KOREAN,
	"Coreano"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_LANG_POLISH,
	"Polaco"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_LANG_PORTUGUESE_BRAZIL,
	"Portugués (Brasil)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_LANG_PORTUGUESE_PORTUGAL,
	"Portugués (Portugal)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_LANG_RUSSIAN,
	"Ruso"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_LANG_SPANISH,
	"Español"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_LANG_VIETNAMESE,
	"Vietnamita"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_LANG_ARABIC,
	"Árabe"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_LEFT_ANALOG,
	"Analógico izquierdo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_LIBRETRO_DIR_PATH,
	"Núcleos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_LIBRETRO_INFO_PATH,
	"Información de núcleos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_LIBRETRO_LOG_LEVEL,
	"Nivel de registro de los núcleos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_LINEAR,
	"Lineal"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_LOAD_ARCHIVE,
	"Cargar archivo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_LOAD_CONTENT_HISTORY,
	"Cargar archivos recientes"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_LOAD_CONTENT_LIST,
	"Cargar Contenido"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_LOAD_STATE,
	"Cargar rápida"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_LOCATION_ALLOW,
	"Permitir ubicación"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_LOCATION_DRIVER,
	"Controlador de ubicación"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_LOGGING_SETTINGS,
	"Registros"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_LOG_VERBOSITY,
	"Verbosidad del registro"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MAIN_MENU,
	"Menú principal"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MANAGEMENT,
	"Ajustes de bases de datos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME,
	"Tema de color del menú"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_BLUE,
	"Azul"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_BLUE_GREY,
	"Azul gris"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_DARK_BLUE,
	"Azul obscuro"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_GREEN,
	"Verde"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_NVIDIA_SHIELD,
	"Shield"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_RED,
	"Rojo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_YELLOW,
	"Amarillo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_FOOTER_OPACITY,
	"Opacidad del pie de página"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_HEADER_OPACITY,
	"Opacidad del encabezado"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MENU_DRIVER,
	"Controlador del menú"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MENU_ENUM_THROTTLE_FRAMERATE,
	"Controlar FPS del menú"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MENU_FILE_BROWSER_SETTINGS,
	"Configuraciones"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MENU_LINEAR_FILTER,
	"Filtro lineal del menú"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MENU_HORIZONTAL_ANIMATION,
	"Animación horizontal"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MENU_SETTINGS,
	"Apariencia"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MENU_WALLPAPER,
	"Fondo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MENU_WALLPAPER_OPACITY,
	"Opacidad del fondo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MISSING,
	"Faltante"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MORE,
	".."
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MOUSE_ENABLE,
	"Soporte para ratón"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MULTIMEDIA_SETTINGS,
	"Multimedia"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MUSIC_TAB,
	"Música"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NAVIGATION_BROWSER_FILTER_SUPPORTED_EXTENSIONS_ENABLE,
	"Filtrar extensiones desconocidas"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NAVIGATION_WRAPAROUND,
	"Volver al inicio al llegar al final"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NEAREST,
	"Mas cercano"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY,
	"Juego en red"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_ALLOW_SLAVES,
	"Permitir clientes en modo esclavo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_CHECK_FRAMES,
	"Juego en red: chequear frames"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_INPUT_LATENCY_FRAMES_MIN,
	"Latencia mínima en frames"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_INPUT_LATENCY_FRAMES_RANGE,
	"Rango de latencia en frames"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_DELAY_FRAMES,
	"Juego en red: retrasar frames"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_DISCONNECT,
	"Desconectar del servidor"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_ENABLE,
	"Activar juego en red"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_ENABLE_CLIENT,
	"Conectar al servidor de juego en red"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_ENABLE_HOST,
	"Iniciar juego en red como servidor"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_DISABLE_HOST,
	"Terminar juego en red"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_IP_ADDRESS,
	"Dirección del servidor"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_LAN_SCAN_SETTINGS,
	"Escanear red local"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_MODE,
	"Activar cliente de juego en red"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_NICKNAME,
	"Apodo para juego en red"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_PASSWORD,
	"Contraseña del servidor"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_PUBLIC_ANNOUNCE,
	"Anunciar juego en red públicamente"
	)
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_REQUEST_DEVICE_I,
	"Pedir dispositivo %u"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_REQUIRE_SLAVES,
	"Desactivar clientes sin modo esclavo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_SETTINGS,
	"Configurar juego en red"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_SHARE_ANALOG,
	"Comparir entrada analoga"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_SHARE_ANALOG_MAX,
	"Max"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_SHARE_ANALOG_AVERAGE,
	"Promedio"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_SHARE_DIGITAL,
	"Compartir entrada digital"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_SHARE_DIGITAL_OR,
	"Compartir"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_SHARE_DIGITAL_XOR,
	"Grapple"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_SHARE_DIGITAL_VOTE,
	"Votar"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_SHARE_NONE,
	"Nada"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_SHARE_NO_PREFERENCE,
	"Sin preferencia"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_START_AS_SPECTATOR,
	"Juego en red: modo espectador"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_STATELESS_MODE,
	"Juego en red: modo sin estado"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_SPECTATE_PASSWORD,
	"Contraseña del servidor para espectadores"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_SPECTATOR_MODE_ENABLE,
	"Juego en red: activar espectadores"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_TCP_UDP_PORT,
	"Juego en red: Puerto TCP"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_NAT_TRAVERSAL,
	"Juego en red: NAT Traversal"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETWORK_CMD_ENABLE,
	"Comandos de red"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETWORK_CMD_PORT,
	"Puerto de comandos de red"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETWORK_INFORMATION,
	"Información de red"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETWORK_REMOTE_ENABLE,
	"Mando en red"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETWORK_REMOTE_PORT,
	"Puerto de base remota de red"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETWORK_SETTINGS,
	"Red"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NO,
	"No"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NONE,
	"Ninguno"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NOT_AVAILABLE,
	"No disponible"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NO_ACHIEVEMENTS_TO_DISPLAY,
	"Sin logros que mostrar"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NO_CORE,
	"Sin núcleo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NO_CORES_AVAILABLE,
	"No hay núcleos disponibles"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NO_CORE_INFORMATION_AVAILABLE,
	"No hay información del núcleo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NO_CORE_OPTIONS_AVAILABLE,
	"No hay opciones del núcleo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NO_ENTRIES_TO_DISPLAY,
	"No hay entradas disponibles"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NO_HISTORY_AVAILABLE,
	"No hay historial disponible"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NO_INFORMATION_AVAILABLE,
	"No hay información disponible"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NO_ITEMS,
	"No hay elementos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NO_NETPLAY_HOSTS_FOUND,
	"No se encontraron anfitriones"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NO_NETWORKS_FOUND,
	"No se encuentran redes"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NO_PERFORMANCE_COUNTERS,
	"No hay contadores de rendimiento"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NO_PLAYLISTS,
	"No hay listas de reproducción"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NO_PLAYLIST_ENTRIES_AVAILABLE,
	"No hay entradas en la lista de reproducción"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NO_SETTINGS_FOUND,
	"No se ha encontrado una configuración"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NO_SHADER_PARAMETERS,
	"No hay parámetros de shaders"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_OFF,
	"OFF"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_ON,
	"ON"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_ONLINE,
	"En línea"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_ONLINE_UPDATER,
	"Actualizador en línea"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_ONSCREEN_DISPLAY_SETTINGS,
	"Información en pantalla (OSD)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_ONSCREEN_OVERLAY_SETTINGS,
	"Overlay"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_ONSCREEN_NOTIFICATIONS_SETTINGS,
	"Notificaciones en pantalla"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_OPEN_ARCHIVE,
	"Explorar archivo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_OPTIONAL,
	"Opcional"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_OVERLAY,
	"Overlay"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_OVERLAY_AUTOLOAD_PREFERRED,
	"Auto-cargar Overlay preferido"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_OVERLAY_DIRECTORY,
	"Overlay"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_OVERLAY_OPACITY,
	"Opacidad de Overlay"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_OVERLAY_PRESET,
	"Overlay Preset"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_OVERLAY_SCALE,
	"Escala de Overlay"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_OVERLAY_SETTINGS,
	"Overlay en pantalla"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_PAL60_ENABLE,
	"Usar modo PAL60"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_PARENT_DIRECTORY,
	"Carpeta superior"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_PAUSE_LIBRETRO,
	"Pausar al activar el menú"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_PAUSE_NONACTIVE,
	"Pausar al quedar en segundo plano"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_PERFCNT_ENABLE,
	"Contadores de rendimiento"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_PLAYLISTS_TAB,
	"Listas de reproducción"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_PLAYLIST_DIRECTORY,
	"Listas de reproducción"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_PLAYLIST_SETTINGS,
	"Listas de reproducción"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_POINTER_ENABLE,
	"Soporte táctil"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_PORT,
	"Puerto"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_PRESENT,
	"Presente"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_PRIVACY_SETTINGS,
	"Privacidad"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_QUIT_RETROARCH,
	"Cerrar RetroArch"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ANALOG,
	"Soporte de analógico"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RDB_ENTRY_BBFC_RATING,
	"BBFC Rating"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RDB_ENTRY_CERO_RATING,
	"CERO Rating"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RDB_ENTRY_COOP,
	"Soporte de Co-op"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RDB_ENTRY_CRC32,
	"CRC32"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RDB_ENTRY_DESCRIPTION,
	"Descripción"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RDB_ENTRY_DEVELOPER,
	"Desarrollador"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RDB_ENTRY_EDGE_MAGAZINE_ISSUE,
	"Edge Magazine Issue"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RDB_ENTRY_EDGE_MAGAZINE_RATING,
	"Edge Magazine Rating"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RDB_ENTRY_EDGE_MAGAZINE_REVIEW,
	"Edge Magazine Review"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ELSPA_RATING,
	"ELSPA Rating"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ENHANCEMENT_HW,
	"Enhancement Hardware"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ESRB_RATING,
	"ESRB Rating"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RDB_ENTRY_FAMITSU_MAGAZINE_RATING,
	"Famitsu Magazine Rating"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RDB_ENTRY_FRANCHISE,
	"Franquicia"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RDB_ENTRY_GENRE,
	"Género"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RDB_ENTRY_MD5,
	"MD5"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RDB_ENTRY_NAME,
	"Nombre"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ORIGIN,
	"Origen"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RDB_ENTRY_PEGI_RATING,
	"PEGI Rating"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RDB_ENTRY_PUBLISHER,
	"Distribuidora"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RDB_ENTRY_RELEASE_MONTH,
	"Mes de lanzamiento"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RDB_ENTRY_RELEASE_YEAR,
	"Año de lanzamiento"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RDB_ENTRY_RUMBLE,
	"Soporte de vibración"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RDB_ENTRY_SERIAL,
	"Serial"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RDB_ENTRY_SHA1,
	"SHA1"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RDB_ENTRY_START_CONTENT,
	"Ejecutar contenido"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RDB_ENTRY_TGDB_RATING,
	"TGDB Rating"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_REBOOT,
	"Reiniciar"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RECORDING_CONFIG_DIRECTORY,
	"Carpeta de configuración de grabación"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RECORDING_OUTPUT_DIRECTORY,
	"Carpeta de salida de grabación"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RECORDING_SETTINGS,
	"Grabación"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RECORD_CONFIG,
	"Cargar configuración de grabación..."
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RECORD_DRIVER,
	"Controlador de grabación"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RECORD_ENABLE,
	"Activar grabación"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RECORD_PATH,
	"Guardar grabación en..."
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RECORD_USE_OUTPUT_DIRECTORY,
	"Usar carpeta de salida"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_REMAP_FILE,
	"Archivo de reasignación de controles"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_REMAP_FILE_LOAD,
	"Cargar archivo de reasignación"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_REMAP_FILE_SAVE_CORE,
	"Guardar controles para el núcleo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_REMAP_FILE_SAVE_GAME,
	"Guardar controles para el juego"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_REMAP_FILE_REMOVE_CORE,
	"Borrar controles personalizados del núcleo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_REMAP_FILE_REMOVE_GAME,
	"Borrar controles personalizados del juego"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_REQUIRED,
	"Necesario"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RESTART_CONTENT,
	"Reiniciar"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RESTART_RETROARCH,
	"Reiniciar RetroArch"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RESUME,
	"Reanudar"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RESUME_CONTENT,
	"Reanudar"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RETROKEYBOARD,
	"RetroKeyboard"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RETROPAD,
	"RetroPad"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RETROPAD_WITH_ANALOG,
	"RetroPad con Analógicos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RETRO_ACHIEVEMENTS_SETTINGS,
	"Logros"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_REWIND_ENABLE,
	"Activar rebobinado"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_REWIND_GRANULARITY,
	"Nivel de detalle del rebobinado"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_REWIND_SETTINGS,
	"Rebobinado"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RGUI_BROWSER_DIRECTORY,
	"Explorador de archivos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RGUI_CONFIG_DIRECTORY,
	"Config"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RGUI_SHOW_START_SCREEN,
	"Mostrar pantalla de inicio"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RIGHT_ANALOG,
	"Analógico derecho"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_ADD_TO_FAVORITES,
	"Agregar a Favoritos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_ADD_TO_FAVORITES_PLAYLIST,
	"Agregar a Favoritos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RUN,
	"Iniciar"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RUN_MUSIC,
	"Iniciar"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SAMBA_ENABLE,
	"Activar SAMBA"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SAVEFILE_DIRECTORY,
	"Partidas guardadas"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SAVESTATE_AUTO_INDEX,
	"Indizar automáticamente guardados rápidos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SAVESTATE_AUTO_LOAD,
	"Cargar guardado rápido automáticamente"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SAVESTATE_AUTO_SAVE,
	"Guardado rápido automático"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SAVESTATE_DIRECTORY,
	"Guardados rápidos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SAVESTATE_THUMBNAIL_ENABLE,
	"Miniaturas de guardados rápidos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SAVE_CURRENT_CONFIG,
	"Guardar configuración actual"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SAVE_CURRENT_CONFIG_OVERRIDE_CORE,
	"Guardar anulaciones del núcleo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SAVE_CURRENT_CONFIG_OVERRIDE_GAME,
	"Guardar anulaciones del juego"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SAVE_NEW_CONFIG,
	"Guardar configuración nueva"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SAVE_STATE,
	"Guardado rápido"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SAVING_SETTINGS,
	"Guardado"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SCAN_DIRECTORY,
	"Escanear carpeta"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SCAN_FILE,
	"Escanear archivo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SCAN_THIS_DIRECTORY,
	"<Escanear esta carpeta>"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SCREENSHOT_DIRECTORY,
	"Capturas de pantalla"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SCREEN_RESOLUTION,
	"Resolución de pantalla"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SEARCH,
	"Buscar"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SECONDS,
	"segundos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SETTINGS,
	"Ajustes"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SETTINGS_TAB,
	"Ajustes"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SHADER,
	"Shader"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SHADER_APPLY_CHANGES,
	"Aplicar cambios"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SHADER_OPTIONS,
	"Shaders"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_RIBBON,
	"Ribbon"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_RIBBON_SIMPLIFIED,
	"Ribbon (simplificado)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_SIMPLE_SNOW,
	"Nieve Simple"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_SNOW,
	"Nieve"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SHOW_ADVANCED_SETTINGS,
	"Mostrar ajustes avanzados"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SHOW_HIDDEN_FILES,
	"Mostrar archivos y carpetas ocultos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SHUTDOWN,
	"Apagar"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SLOWMOTION_RATIO,
	"Velocidad de cámara lenta"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SORT_SAVEFILES_ENABLE,
	"Ordenar partidas guardadas por carpetas"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SORT_SAVESTATES_ENABLE,
	"Ordenar guardados rápidos por carpetas"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SAVESTATES_IN_CONTENT_DIR_ENABLE,
	"Escribir guardado rápido en la carpeta del contenido"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SAVEFILES_IN_CONTENT_DIR_ENABLE,
	"Escribir partida guardada en la carpeta del contenido"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEMFILES_IN_CONTENT_DIR_ENABLE,
	"Archivos de Sistema están en la carpeta del contenido"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SCREENSHOTS_IN_CONTENT_DIR_ENABLE,
	"Escribir capturas de pantalla en la carpeta del contenido"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SSH_ENABLE,
	"Activar SSH"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_START_CORE,
	"Iniciar núcleo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_START_NET_RETROPAD,
	"Iniciar RetroPad remoto"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_START_VIDEO_PROCESSOR,
	"Iniciar procesador de video"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_STATE_SLOT,
	"Ranura de guardado"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_STATUS,
	"Estado"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_STDIN_CMD_ENABLE,
	"Comandos stdin"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SUPPORTED_CORES,
	"Núcleos sugeridos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SUSPEND_SCREENSAVER_ENABLE,
	"Suspender salvapantallas"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_BGM_ENABLE,
	"Activar música del sistema"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_DIRECTORY,
	"Sistema/BIOS"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFORMATION,
	"Información del sistema"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_7ZIP_SUPPORT,
	"Soporte de 7zip"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_ALSA_SUPPORT,
	"Soporte de ALSA"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_BUILD_DATE,
	"Fecha de compilación"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_CG_SUPPORT,
	"Soporte de Cg"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_COCOA_SUPPORT,
	"Soporte de Cocoa"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_COMMAND_IFACE_SUPPORT,
	"Soporte de interfaz de comandos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_CORETEXT_SUPPORT,
	"Soporte de CoreText"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_CPU_FEATURES,
	"Características de CPU"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DISPLAY_METRIC_DPI,
	"Mostrar DPI métricos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DISPLAY_METRIC_MM_HEIGHT,
	"Mostrar alto métrico (mm)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DISPLAY_METRIC_MM_WIDTH,
	"Mostrar ancho métrico (mm)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DSOUND_SUPPORT,
	"Soporte de DirectSound"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_WASAPI_SUPPORT,
	"Soporte de WASAPI"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DYLIB_SUPPORT,
	"Soporte de librerías dinámicas"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DYNAMIC_SUPPORT,
	"Carga dinámica en tiempo real de librería libretro"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_EGL_SUPPORT,
	"Soporte de EGL"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FBO_SUPPORT,
	"Soporte de render-to-texture OpenGL/Direct3D (shaders multipasos)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FFMPEG_SUPPORT,
	"Soporte de FFmpeg"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FREETYPE_SUPPORT,
	"Soporte de FreeType"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FRONTEND_IDENTIFIER,
	"Identificador del frontend"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FRONTEND_NAME,
	"Nombre del frontend"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FRONTEND_OS,
	"S.O. del frontend"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_GIT_VERSION,
	"Versión de Git"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_GLSL_SUPPORT,
	"Soporte de GLSL"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_HLSL_SUPPORT,
	"Soporte de HLSL"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_JACK_SUPPORT,
	"Soporte de JACK"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_KMS_SUPPORT,
	"Soporte de KMS/EGL"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_LAKKA_VERSION,
	"Versión de Lakka"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_LIBRETRODB_SUPPORT,
	"Soporte de LibretroDB"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_LIBUSB_SUPPORT,
	"Soporte de Libusb"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_LIBXML2_SUPPORT,
	"Soporte de parseo XML libxml2"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_NETPLAY_SUPPORT,
	"Soporte de juego en red (peer-to-peer)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_NETWORK_COMMAND_IFACE_SUPPORT,
	"Soporte de interfaz de comandos en red"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_NETWORK_REMOTE_SUPPORT,
	"Soporte de mando en red"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENAL_SUPPORT,
	"Soporte de OpenAL"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENGLES_SUPPORT,
	"Soporte de OpenGL ES"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENGL_SUPPORT,
	"Soporte de OpenGL"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENSL_SUPPORT,
	"Soporte de OpenSL"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENVG_SUPPORT,
	"Soporte de OpenVG"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OSS_SUPPORT,
	"Soporte de OSS"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OVERLAY_SUPPORT,
	"Soporte de Overlay"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE,
	"Fuente de alimentación"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE_CHARGED,
	"Cargada"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE_CHARGING,
	"Cargando"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE_DISCHARGING,
	"Descargando"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE_NO_SOURCE,
	"No hay una fuente"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_PULSEAUDIO_SUPPORT,
	"Soporte de PulseAudio"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_PYTHON_SUPPORT,
	"Soporte de Python (soporte de scripts para shaders)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RBMP_SUPPORT,
	"Soporte de BMP  (RBMP)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RETRORATING_LEVEL,
	"Nivel de RetroRating"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RJPEG_SUPPORT,
	"Soporte de JPEG (RJPEG)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_ROARAUDIO_SUPPORT,
	"Soporte de RoarAudio"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RPNG_SUPPORT,
	"Soporte de PNG (RPNG)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RSOUND_SUPPORT,
	"Soporte de RSound"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RTGA_SUPPORT,
	"Soporte de TGA (RTGA)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_SDL2_SUPPORT,
	"Soporte de SDL2"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_SDL_IMAGE_SUPPORT,
	"Soporte de imágenes SDL"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_SDL_SUPPORT,
	"Soporte de SDL1.2"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_SLANG_SUPPORT,
	"Soporte de Slang"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_THREADING_SUPPORT,
	"Soporte de hilos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_UDEV_SUPPORT,
	"Soporte de Udev"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_V4L2_SUPPORT,
	"Soporte de Video4Linux2"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_VIDEO_CONTEXT_DRIVER,
	"Controlador de contexto de video"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_VULKAN_SUPPORT,
	"Soporte Vulkan"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_WAYLAND_SUPPORT,
	"Soporte de Wayland"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_X11_SUPPORT,
	"Soporte de X11"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_XAUDIO2_SUPPORT,
	"Soporte de XAudio2"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_XVIDEO_SUPPORT,
	"Soporte de XVideo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_ZLIB_SUPPORT,
	"Soporte de Zlib"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_TAKE_SCREENSHOT,
	"Capturar pantalla"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_THREADED_DATA_RUNLOOP_ENABLE,
	"Tareas en hilos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_THUMBNAILS,
	"Miniaturas"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_THUMBNAILS_DIRECTORY,
	"Miniaturas"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_THUMBNAILS_UPDATER_LIST,
	"Actualizador de miniaturas"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_THUMBNAIL_MODE_BOXARTS,
	"Cajas"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_THUMBNAIL_MODE_SCREENSHOTS,
	"Capturas de pantalla"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_THUMBNAIL_MODE_TITLE_SCREENS,
	"Pantallas de título"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_TIMEDATE_ENABLE,
	"Mostrar fecha y hora"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_TITLE_COLOR,
	"Color de títulos del menú"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_TRUE,
	"Activado"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_UI_COMPANION_ENABLE,
	"Activar IU ayudante"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_UI_COMPANION_START_ON_BOOT,
	"Ejecutar al inicio la IU ayudante"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_UI_MENUBAR_ENABLE,
	"Barra de menús"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_UNABLE_TO_READ_COMPRESSED_FILE,
	"No se ha podido leer el archivo comprimido"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_UNDO_LOAD_STATE,
	"Deshacer carga"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_UNDO_SAVE_STATE,
	"Deshacer guardado"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_UNKNOWN,
	"Desconocido"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_UPDATER_SETTINGS,
	"Actualizador"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_UPDATE_ASSETS,
	"Actualizar recursos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_UPDATE_AUTOCONFIG_PROFILES,
	"Actualizar perfiles de auto-configuración"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_UPDATE_CG_SHADERS,
	"Actualizar shaders Cg"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_UPDATE_CHEATS,
	"Actualizar trucos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_UPDATE_CORE_INFO_FILES,
	"Actualizar archivos de info de núcleo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_UPDATE_DATABASES,
	"Actualizar bases de datos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_UPDATE_GLSL_SHADERS,
	"Actualizar shaders GLSL"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_UPDATE_LAKKA,
	"Actualizar Lakka"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_UPDATE_OVERLAYS,
	"Actualizar Overlays"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_UPDATE_SLANG_SHADERS,
	"Actualizar shaders Slang"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_USER,
	"Usuario"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_KEYBOARD,
	"Teclado"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_USER_INTERFACE_SETTINGS,
	"Interfaz de usuario"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_USER_LANGUAGE,
	"Idioma"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_USER_SETTINGS,
	"Usuario"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_USE_BUILTIN_IMAGE_VIEWER,
	"Usar visor de imágenes integrado"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_USE_BUILTIN_PLAYER,
	"Usar visor de medios integrado"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_USE_THIS_DIRECTORY,
	"<Usar esta carpeta>"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_ALLOW_ROTATE,
	"Permitir rotación"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_ASPECT_RATIO,
	"Configurar relación de aspecto"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_ASPECT_RATIO_AUTO,
	"Relación de aspecto automática"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_ASPECT_RATIO_INDEX,
	"Relación de aspecto"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_BLACK_FRAME_INSERTION,
	"Insertar frames negros"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_CROP_OVERSCAN,
	"Recortar Overscan (Reinicio)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_DISABLE_COMPOSITION,
	"Desactivar composición de escritorio"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_DRIVER,
	"Controlador de video"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_FILTER,
	"Filtro de video"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_FILTER_DIR,
	"Video Filter"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_FILTER_FLICKER,
	"Flicker filter"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_FONT_ENABLE,
	"Mostrar notificaciones en pantalla"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_FONT_PATH,
	"Fuente de notificación"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_FONT_SIZE,
	"Tamaño de notificación"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_FORCE_ASPECT,
	"Forzar relación de aspecto"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_FORCE_SRGB_DISABLE,
	"Forzar desactivación del FBO sRGB"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_FRAME_DELAY,
	"Retraso de frames"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_FULLSCREEN,
	"Iniciar en pantalla completa"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_GAMMA,
	"Gamma de video"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_GPU_RECORD,
	"Activar grabación de GPU"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_GPU_SCREENSHOT,
	"Permitir capturas de pantalla de GPU"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_HARD_SYNC,
	"Sincronía estricta de GPU"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_HARD_SYNC_FRAMES,
	"Frames para sincronía estricta"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_MAX_SWAPCHAIN_IMAGES,
	"Máximo de imágenes en swapchain"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_POS_X,
	"Posición X de notificaciones"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_POS_Y,
	"Posición Y de notificaciones"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_MONITOR_INDEX,
	"Índice del monitor"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_POST_FILTER_RECORD,
	"Activar grabación con filtros"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_REFRESH_RATE,
	"Frecuencia de actualización"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_REFRESH_RATE_AUTO,
	"Frecuencia estimada del monitor"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_REFRESH_RATE_POLLED,
	"Set Display-Reported Refresh Rate"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_ROTATION,
	"Rotación"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_SCALE,
	"Escala en ventana"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_SCALE_INTEGER,
	"Escalar usando enteros"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_SETTINGS,
	"Video"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_DIR,
	"Video Shader"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_NUM_PASSES,
	"Pasadas del shader"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PARAMETERS,
	"Previsualizar parámetros de shaders"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PRESET,
	"Cargar preset de shaders"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PRESET_SAVE_AS,
	"Guardar preset de shaders como.."
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PRESET_SAVE_CORE,
	"Guardar preset para el núcleo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PRESET_SAVE_GAME,
	"Guardar preset para el juego"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_SHARED_CONTEXT,
	"Activar contexto compartido por HW"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_SMOOTH,
	"Filtrado bilineal"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_SOFT_FILTER,
	"Activar filtros por software"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_SWAP_INTERVAL,
	"Vertical Sync (Vsync) Swap Interval"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_TAB,
	"Video"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_THREADED,
	"Video por hilos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_VFILTER,
	"Filtro contra parpadeos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_VIEWPORT_CUSTOM_HEIGHT,
	"Custom Aspect Ratio Height"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_VIEWPORT_CUSTOM_WIDTH,
	"Custom Aspect Ratio Width"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_VIEWPORT_CUSTOM_X,
	"Custom Aspect Ratio X Pos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_VIEWPORT_CUSTOM_Y,
	"Custom Aspect Ratio Y Pos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_VI_WIDTH,
	"Asignar ancho de interfaz visual"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_VSYNC,
	"Sincronía vertical (VSync)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_WINDOWED_FULLSCREEN,
	"Pantalla completa en ventana"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_WINDOW_WIDTH,
	"Ancho de la ventana"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_WINDOW_HEIGHT,
	"Alto de la ventana"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_FULLSCREEN_X,
	"Ancho en pantalla completa"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_FULLSCREEN_Y,
	"Alto en pantalla completa"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_WIFI_DRIVER,
	"Controlador Wi-Fi"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_WIFI_SETTINGS,
	"Wi-Fi"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_XMB_ALPHA_FACTOR,
	"Transparencia del menú"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MENU_FONT_COLOR_RED,
	"Fuente del Menú componente roja"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MENU_FONT_COLOR_GREEN,
	"Fuente del Menú componente verde"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MENU_FONT_COLOR_BLUE,
	"Fuente del Menú componente azul"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_XMB_FONT,
	"Fuente del menú"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_CUSTOM,
	"Custom"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_FLATUI,
	"FlatUI"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_MONOCHROME,
	"Monochrome"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_MONOCHROME_INVERTED,
	"Monochrome Invertido"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_SYSTEMATIC,
	"Systematic"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_NEOACTIVE,
	"NeoActive"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_PIXEL,
	"Pixel"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_RETROACTIVE,
	"RetroActive"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_RETROSYSTEM,
	"Retrosystem"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_DOTART,
	"Dot-Art"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME,
	"Color del menú"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_APPLE_GREEN,
	"Verde manzana"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_DARK,
	"Oscuro"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_LIGHT,
	"Claro"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_DARK_PURPLE,
	"Violeta"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_ELECTRIC_BLUE,
	"Azul Eléctrico"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_GOLDEN,
	"Dorado"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_LEGACY_RED,
	"Rojo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_MIDNIGHT_BLUE,
	"Azul Medianoche"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_PLAIN,
	"Nada"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_UNDERSEA,
	"Bajo el mar"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_VOLCANIC_RED,
	"Rojo Volcánico"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_XMB_RIBBON_ENABLE,
	"Menú Shader Pipeline"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_XMB_SCALE_FACTOR,
	"Escala del menú"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_XMB_SHADOWS_ENABLE,
	"Sombras de iconos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_HISTORY,
	"Mostrar pestaña historial"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_ADD,
	"Mostrar pestaña importar contenido"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_FAVORITES,
	"Mostrar pestaña favoritos"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_IMAGES,
	"Mostrar pestaña imágenes"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_MUSIC,
	"Mostrar pestaña música"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_SETTINGS,
	"Mostrar pestaña configuración"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_VIDEO,
	"Mostrar pestaña video"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_NETPLAY,
	"Mostrar pestaña juego en red"
	)
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_LAYOUT,
      "Menu Layout")
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_XMB_THEME,
	"Tema de iconos del menú"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_YES,
	"Sí"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VIDEO_SHADER_PRESET_TWO,
	"Preset de shader"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CHEEVOS_ENABLE,
	"Activar logros. Para más información, visita http://retroachievements.org"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CHEEVOS_TEST_UNOFFICIAL,
	"Activar logros no oficiales y/o beta para probarlos"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CHEEVOS_HARDCORE_MODE_ENABLE,
	"Duplica puntos pero desactiva guardado rápido, trucos, rebobinar, y cámara lenta para todos los juegos"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CHEEVOS_LEADERBOARDS_ENABLE,
	"No tiene efecto si el modo hardcore está desactivado"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CHEEVOS_BADGES_ENABLE,
	"Activar para ver miniaturas en la lista de logros"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CHEEVOS_VERBOSE_ENABLE,
	"Activar para ver notificaciones mas informativas sobre logros"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_DRIVER_SETTINGS,
	"Cambia los controladores usados por el sistema"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_RETRO_ACHIEVEMENTS_SETTINGS,
	"Opciones de los logros"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CORE_SETTINGS,
	"Opciones de los núcleos"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_RECORDING_SETTINGS,
	"Opciones de grabación"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_ONSCREEN_DISPLAY_SETTINGS,
	"Opciones de notificaciones, teclado en pantalla y overlays"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_FRAME_THROTTLE_SETTINGS,
	"Opciones de rebobinado, adelantado y cámara lenta"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_SAVING_SETTINGS,
	"Opciones de guardado"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_LOGGING_SETTINGS,
	"Opciones de registro"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_USER_INTERFACE_SETTINGS,
	"Opciones de la interfaz de usuario"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_USER_SETTINGS,
	"Opciones de cuentas, nombre de usuario y lenguaje"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_PRIVACY_SETTINGS,
	"Opciones de privacidad"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_DIRECTORY_SETTINGS,
	"Cambia las carpetas por defecto donde se encuentran los archivos"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_PLAYLIST_SETTINGS,
	"Opciones de las listas de juegos"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_NETWORK_SETTINGS,
	"Opciones de servidor y red"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_ADD_CONTENT_LIST,
	"Escanear contenido y agregar a la base de datos"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_AUDIO_SETTINGS,
	"Opciones de salida de audio"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_BLUETOOTH_ENABLE,
	"Activar o desactivar Bluetooth"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CONFIG_SAVE_ON_EXIT,
	"Guarda los cambios en el archivo de configuración al salir"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CONFIGURATION_SETTINGS,
	"Opciones de los archivos de configuración"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CONFIGURATIONS_LIST,
	"Administrar y crear archivos de configuración"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CPU_CORES,
	"Cantidad de núcleos que tiene la CPU"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_FPS_SHOW,
	"Muestra la velocidad de cuadros por segundo"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_INPUT_HOTKEY_BINDS,
	"Opciones de teclas rápidas (hotkeys)"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_INPUT_MENU_ENUM_TOGGLE_GAMEPAD_COMBO,
	"Combinación de botones del mando para mostrar el menú"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_INPUT_SETTINGS,
	"Opciones de mando, teclado y ratón"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_INPUT_USER_BINDS,
	"Cambiar los controles para este usuario"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_LOG_VERBOSITY,
	"Activar o desactivar registros a la terminal"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_NETPLAY,
	"Unirse o ser servidor de una sesión de juego en red"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_NETPLAY_LAN_SCAN_SETTINGS,
	"Buscar y conectarse a anfitriones de juego en red en la red local"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_INFORMATION_LIST_LIST,
	"Muestra la información de sistema"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_ONLINE_UPDATER,
	"Descarga componentes y contenido adicional para RetroArch"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_SAMBA_ENABLE,
	"Activar o desactivar el compartido de carpetas en red"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_SERVICES_SETTINGS,
	"Administrar los servicios del sistema operativo"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_SHOW_HIDDEN_FILES,
	"Mostrar archivos y carpetas ocultos en el explorador de archivos"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_SSH_ENABLE,
	"Activar o desactivar acceso remoto por linea de comandos"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_SUSPEND_SCREENSAVER_ENABLE,
	"Evita que el protector de pantalla se active"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_WINDOW_SCALE,
	"Hacer que el tamaño de la ventana sea relativo al núcleo. Alternativamente, puedes fijar el tamaño mas abajo"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_USER_LANGUAGE,
	"Cambia el lenguaje de la interfaz"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_BLACK_FRAME_INSERTION,
	"Insertar un cuadro negro intermedio, Útil para usuarios con pantallas de 120hz que quieren eliminar ghosting en el contenido de 60hz"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_FRAME_DELAY,
	"Reducir latencia a costa de un mayor riesgo de stuttering. Agrega un retraso después del VSync en milisegundos"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_HARD_SYNC_FRAMES,
	"Cuantos cuadros puede ir la CPU por delante de la GPU al usar 'Sincronía estricta de GPU'"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_MAX_SWAPCHAIN_IMAGES,
	"Informa al controlador que use el modo de buffering especificado"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_MONITOR_INDEX,
	"Seleccionar la pantalla a usar"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_REFRESH_RATE_AUTO,
	"Estimado preciso de refresco de la pantalla en Hz"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_REFRESH_RATE_POLLED,
	"The refresh rate as reported by the display driver."
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_SETTINGS,
	"Opciones de salida de video"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_WIFI_SETTINGS,
	"Escanear redes inalambricas y conectarse"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_HELP_LIST,
	"Aprender como funciona el programa"
	)
MSG_HASH(
	MSG_ADDED_TO_FAVORITES,
	"Agregado a los favoritos"
	)
MSG_HASH(
	MSG_APPENDED_DISK,
	"Disco encolado"
	)
MSG_HASH(
	MSG_APPLICATION_DIR,
	"Carpeta de la aplicación"
	)
MSG_HASH(
	MSG_APPLYING_CHEAT,
	"Aplicando trucos"
	)
MSG_HASH(
	MSG_APPLYING_SHADER,
	"Aplicando shader"
	)
MSG_HASH(
	MSG_AUDIO_MUTED,
	"Silencio"
	)
MSG_HASH(
	MSG_AUDIO_UNMUTED,
	"Audio normal"
	)
MSG_HASH(
	MSG_AUTOCONFIG_FILE_ERROR_SAVING,
	"Error guardando archivo de auto-configuración"
	)
MSG_HASH(
	MSG_AUTOCONFIG_FILE_SAVED_SUCCESSFULLY,
	"Archivo de auto-configuración guardado exitosamente"
	)
MSG_HASH(
	MSG_AUTOSAVE_FAILED,
	"No se puede inicializar autogurardado"
	)
MSG_HASH(
	MSG_AUTO_SAVE_STATE_TO,
	"Auto guardar en"
	)
MSG_HASH(
	MSG_BLOCKING_SRAM_OVERWRITE,
	"Bloquear sobrescritura de SaveRAM"
	)
MSG_HASH(
	MSG_BRINGING_UP_COMMAND_INTERFACE_ON_PORT,
	"Iniciando la linea de comandos en el puerto"
	)
MSG_HASH(
	MSG_BYTES,
	"bytes"
	)
MSG_HASH(
	MSG_CANNOT_INFER_NEW_CONFIG_PATH,
	"No se puede inferir la nueva ruta de configuración. Use el tiempo actual"
	)
MSG_HASH(
	MSG_CHEEVOS_HARDCORE_MODE_ENABLE,
	"Modo hardcore activado, guardado rápido y rebobinado deshabilitados"
	)
MSG_HASH(
	MSG_COMPARING_WITH_KNOWN_MAGIC_NUMBERS,
	"Comparando con números mágicos conocidos.."
	)
MSG_HASH(
	MSG_COMPILED_AGAINST_API,
	"Compilado para la API"
	)
MSG_HASH(
	MSG_CONFIG_DIRECTORY_NOT_SET,
	"Carpeta de configuración no establecida. No se puede guardar la configuración"
	)
MSG_HASH(
	MSG_CONNECTED_TO,
	"Conectado a"
	)
MSG_HASH(
	MSG_CONTENT_CRC32S_DIFFER,
	"No se pueden usar diferentes juegos. (El CRC32s difiere)"
	)
MSG_HASH(
	MSG_CONTENT_LOADING_SKIPPED_IMPLEMENTATION_WILL_DO_IT,
	"Carga de contenido saltada. La implementación usara la suya"
	)
MSG_HASH(
	MSG_CORE_DOES_NOT_SUPPORT_SAVESTATES,
	"El núcleo no soporta guardados rápidos"
	)
MSG_HASH(
	MSG_CORE_OPTIONS_FILE_CREATED_SUCCESSFULLY,
	"Archivo de opciones del núcleo creado exitosamente"
	)
MSG_HASH(
	MSG_COULD_NOT_FIND_ANY_NEXT_DRIVER,
	"No se encuentra otro controlador"
	)
MSG_HASH(
	MSG_COULD_NOT_FIND_COMPATIBLE_SYSTEM,
	"No se encuentra un sistema compatible"
	)
MSG_HASH(
	MSG_COULD_NOT_FIND_VALID_DATA_TRACK,
	"No se encuentra una pista de datos válido"
	)
MSG_HASH(
	MSG_COULD_NOT_OPEN_DATA_TRACK,
	"No se puede abrir la pista de datos"
	)
MSG_HASH(
	MSG_COULD_NOT_READ_CONTENT_FILE,
	"No se puede leer el contenido"
	)
MSG_HASH(
	MSG_COULD_NOT_READ_MOVIE_HEADER,
	"No se puede leer el encabezado de la película"
	)
MSG_HASH(
	MSG_COULD_NOT_READ_STATE_FROM_MOVIE,
	"No se puede leer el estado del película"
	)
MSG_HASH(
	MSG_CRC32_CHECKSUM_MISMATCH,
	"El CRC32 del contenido no concuerda con el del replay, Es probable que se de-sincronice al reproducir"
	)
MSG_HASH(
	MSG_CUSTOM_TIMING_GIVEN,
	"Custom timing given"
	)
MSG_HASH(
	MSG_DECOMPRESSION_ALREADY_IN_PROGRESS,
	"Descompresión en progreso"
	)
MSG_HASH(
	MSG_DECOMPRESSION_FAILED,
	"Fallo al descomprimir"
	)
MSG_HASH(
	MSG_DETECTED_VIEWPORT_OF,
	"Detectado viewport de"
	)
MSG_HASH(
	MSG_DID_NOT_FIND_A_VALID_CONTENT_PATCH,
	"No se encontró un parche válido"
	)
MSG_HASH(
	MSG_DISCONNECT_DEVICE_FROM_A_VALID_PORT,
	"Desconecte el dispositivo desde un puerto válido"
	)
MSG_HASH(
	MSG_DISK_CLOSED,
	"Cerrado"
	)
MSG_HASH(
	MSG_DISK_EJECTED,
	"Expulsado"
	)
MSG_HASH(
	MSG_DOWNLOADING,
	"Descargando"
	)
MSG_HASH(
	MSG_DOWNLOAD_FAILED,
	"Descarga fallida"
	)
MSG_HASH(
	MSG_ERROR,
	"Error"
	)
MSG_HASH(
	MSG_ERROR_LIBRETRO_CORE_REQUIRES_CONTENT,
	"El núcleo Libretro necesita contenido, pero no se le propicio."
	)
MSG_HASH(
	MSG_ERROR_LIBRETRO_CORE_REQUIRES_SPECIAL_CONTENT,
	"El núcleo Libretro necesita contenido especial, pero no se le propicio."
	)
MSG_HASH(
	MSG_ERROR_PARSING_ARGUMENTS,
	"Error analizando argumentos"
	)
MSG_HASH(
	MSG_ERROR_SAVING_CORE_OPTIONS_FILE,
	"Error guardando archivo de opciones del núcleo"
	)
MSG_HASH(
	MSG_ERROR_SAVING_REMAP_FILE,
	"Error guardando archivo de reasignación"
	)
MSG_HASH(
	MSG_ERROR_REMOVING_REMAP_FILE,
	"Error eliminado archivo de reasignación"
	)
MSG_HASH(
	MSG_ERROR_SAVING_SHADER_PRESET,
	"Error guardando shader preset"
	)
MSG_HASH(
	MSG_EXTERNAL_APPLICATION_DIR,
	"Carpeta de aplicación externa"
	)
MSG_HASH(
	MSG_EXTRACTING,
	"Extrayendo"
	)
MSG_HASH(
	MSG_EXTRACTING_FILE,
	"Extrayendo archivo"
	)
MSG_HASH(
	MSG_FAILED_SAVING_CONFIG_TO,
	"Fallo al guardar configuración en"
	)
MSG_HASH(
	MSG_FAILED_TO,
	"Fallo al"
	)
MSG_HASH(
	MSG_FAILED_TO_ACCEPT_INCOMING_SPECTATOR,
	"Fallo al aceptar al espectador"
	)
MSG_HASH(
	MSG_FAILED_TO_ALLOCATE_MEMORY_FOR_PATCHED_CONTENT,
	"Fallo al reservar memoria para el contenido parcheado"
	)
MSG_HASH(
	MSG_FAILED_TO_APPLY_SHADER,
	"Fallo al aplicar el shader"
	)
MSG_HASH(
	MSG_FAILED_TO_BIND_SOCKET,
	"Fallo al asignar el socket"
	)
MSG_HASH(
	MSG_FAILED_TO_CREATE_THE_DIRECTORY,
	"Fallo al crear la carpeta"
	)
MSG_HASH(
	MSG_FAILED_TO_EXTRACT_CONTENT_FROM_COMPRESSED_FILE,
	"Fallo al extraer el contenido desde el archivo comprimido"
	)
MSG_HASH(
	MSG_FAILED_TO_GET_NICKNAME_FROM_CLIENT,
	"Fallo al obtener el apodo del cliente"
	)
MSG_HASH(
	MSG_FAILED_TO_LOAD,
	"Fallo al cargar"
	)
MSG_HASH(
	MSG_FAILED_TO_LOAD_CONTENT,
	"Fallo al cargar contenido"
	)
MSG_HASH(
	MSG_FAILED_TO_LOAD_MOVIE_FILE,
	"Fallo al cargar la película"
	)
MSG_HASH(
	MSG_FAILED_TO_LOAD_OVERLAY,
	"Fallo al cargar overlay"
	)
MSG_HASH(
	MSG_FAILED_TO_LOAD_STATE,
	"Fallo al cargar guardado de"
	)
MSG_HASH(
	MSG_FAILED_TO_OPEN_LIBRETRO_CORE,
	"Fallo al abrir el núcleo Libretro"
	)
MSG_HASH(
	MSG_FAILED_TO_PATCH,
	"Fallo el parcheado"
	)
MSG_HASH(
	MSG_FAILED_TO_RECEIVE_HEADER_FROM_CLIENT,
	"Fallo al recibir el encabezado desde el cliente"
	)
MSG_HASH(
	MSG_FAILED_TO_RECEIVE_NICKNAME,
	"Fallo al recibir el apodo"
	)
MSG_HASH(
	MSG_FAILED_TO_RECEIVE_NICKNAME_FROM_HOST,
	"Fallo al recibir el apodo del servidor"
	)
MSG_HASH(
	MSG_FAILED_TO_RECEIVE_NICKNAME_SIZE_FROM_HOST,
	"Fallo al recibir el tamaño del apodo del servidor"
	)
MSG_HASH(
	MSG_FAILED_TO_RECEIVE_SRAM_DATA_FROM_HOST,
	"Fallo al recibir datos SaveRAM del servidor"
	)
MSG_HASH(
	MSG_FAILED_TO_REMOVE_DISK_FROM_TRAY,
	"Fallo al sacar el disco de la bandeja"
	)
MSG_HASH(
	MSG_FAILED_TO_REMOVE_TEMPORARY_FILE,
	"Fallo al eliminar el archivo temporal"
	)
MSG_HASH(
	MSG_FAILED_TO_SAVE_SRAM,
	"Fallo al guardar SaveRAM"
	)
MSG_HASH(
	MSG_FAILED_TO_SAVE_STATE_TO,
	"Fallo al guardar en"
	)
MSG_HASH(
	MSG_FAILED_TO_SEND_NICKNAME,
	"Fallo al enviar el apodo"
	)
MSG_HASH(
	MSG_FAILED_TO_SEND_NICKNAME_SIZE,
	"Fallo al enviar el tamaño del apodo"
	)
MSG_HASH(
	MSG_FAILED_TO_SEND_NICKNAME_TO_CLIENT,
	"Fallo al enviar el apodo al cliente"
	)
MSG_HASH(
	MSG_FAILED_TO_SEND_NICKNAME_TO_HOST,
	"Fallo al enviar el apodo al servidor"
	)
MSG_HASH(
	MSG_FAILED_TO_SEND_SRAM_DATA_TO_CLIENT,
	"Fallo al enviar datos SaveRAM al cliente"
	)
MSG_HASH(
	MSG_FAILED_TO_START_AUDIO_DRIVER,
	"Fallo al iniciar el controlador de audio. Se continuará en silencio"
	)
MSG_HASH(
	MSG_FAILED_TO_START_MOVIE_RECORD,
	"Fallo al iniciar clip de grabación"
	)
MSG_HASH(
	MSG_FAILED_TO_START_RECORDING,
	"Fallo al iniciar grabación"
	)
MSG_HASH(
	MSG_FAILED_TO_TAKE_SCREENSHOT,
	"Fallo al capturar pantalla"
	)
MSG_HASH(
	MSG_FAILED_TO_UNDO_LOAD_STATE,
	"Fallo al deshacer carga"
	)
MSG_HASH(
	MSG_FAILED_TO_UNDO_SAVE_STATE,
	"Fallo al deshacer guardado"
	)
MSG_HASH(
	MSG_FAILED_TO_UNMUTE_AUDIO,
	"Fallo al restablecer el audio"
	)
MSG_HASH(
	MSG_FATAL_ERROR_RECEIVED_IN,
	"Fatal error recibido en"
	)
MSG_HASH(
	MSG_FILE_NOT_FOUND,
	"Archivo no encontrado"
	)
MSG_HASH(
	MSG_FOUND_AUTO_SAVESTATE_IN,
	"Encontrado autoguardado en"
	)
MSG_HASH(
	MSG_FOUND_DISK_LABEL,
	"Encontrada la etiqueta del disco"
	)
MSG_HASH(
	MSG_FOUND_FIRST_DATA_TRACK_ON_FILE,
	"Encontrada la primer pista de datos en el archivo"
	)
MSG_HASH(
	MSG_FOUND_LAST_STATE_SLOT,
	"Encontrada la ultima ranura de guardado"
	)
MSG_HASH(
	MSG_FOUND_SHADER,
	"Encontrado el shader"
	)
MSG_HASH(
	MSG_FRAMES,
	"Frames"
	)
MSG_HASH(
	MSG_GAME_SPECIFIC_CORE_OPTIONS_FOUND_AT,
	"Opciones especificas de juego encontradas en"
	)
MSG_HASH(
	MSG_GOT_INVALID_DISK_INDEX,
	"Indice de disco invalido"
	)
MSG_HASH(
	MSG_GRAB_MOUSE_STATE,
	"Capturar estado del ratón"
	)
MSG_HASH(
	MSG_GAME_FOCUS_ON,
	"Game focus ON"
	)
MSG_HASH(
	MSG_GAME_FOCUS_OFF,
	"Game focus OFF"
	)
MSG_HASH(
	MSG_HW_RENDERED_MUST_USE_POSTSHADED_RECORDING,
	"El núcleo Libretro esta renderizado por hardware. Debe usar grabaciones post-shaded"
	)
MSG_HASH(
	MSG_INFLATED_CHECKSUM_DID_NOT_MATCH_CRC32,
	"El CRC32 inflado no concuerda"
	)
MSG_HASH(
	MSG_INPUT_CHEAT,
	"Introducir truco"
	)
MSG_HASH(
	MSG_INPUT_CHEAT_FILENAME,
	"Introducir nombre de archivo de truco"
	)
MSG_HASH(
	MSG_INPUT_PRESET_FILENAME,
	"Introducir nombre de archivo del preset"
	)
MSG_HASH(
	MSG_INPUT_RENAME_ENTRY,
	"Renombrar titulo"
	)
MSG_HASH(
	MSG_INTERFACE,
	"Interfaz"
	)
MSG_HASH(
	MSG_INTERNAL_STORAGE,
	"Almacenamiento interno"
	)
MSG_HASH(
	MSG_REMOVABLE_STORAGE,
	"Almacenamiento extraible"
	)
MSG_HASH(
	MSG_INVALID_NICKNAME_SIZE,
	"Tamaño de apodo invalido"
	)
MSG_HASH(
	MSG_IN_BYTES,
	"en bytes"
	)
MSG_HASH(
	MSG_IN_GIGABYTES,
	"en gigabytes"
	)
MSG_HASH(
	MSG_IN_MEGABYTES,
	"en megabytes"
	)
MSG_HASH(
	MSG_LIBRETRO_ABI_BREAK,
	"está compilado para otra versión de Libretro"
	)
MSG_HASH(
	MSG_LIBRETRO_FRONTEND,
	"Interfaz de usuario para Libretro"
	)
MSG_HASH(
	MSG_LOADED_STATE_FROM_SLOT,
	"Cargado guardado de la ranura #%d"
	)
MSG_HASH(
	MSG_LOADED_STATE_FROM_SLOT_AUTO,
	"Cargado guardado de la ranura #-1 (auto)"
	)
MSG_HASH(
	MSG_LOADING,
	"Cargando"
	)
MSG_HASH(
	MSG_FIRMWARE,
	"Faltan archivos de firmware"
	)
MSG_HASH(
	MSG_LOADING_CONTENT_FILE,
	"Cargando contenido"
	)
MSG_HASH(
	MSG_LOADING_HISTORY_FILE,
	"Cargando historial"
	)
MSG_HASH(
	MSG_LOADING_STATE,
	"Cargando estado"
	)
MSG_HASH(
	MSG_MEMORY,
	"Memoria"
	)
MSG_HASH(
	MSG_MOVIE_FILE_IS_NOT_A_VALID_BSV1_FILE,
	"La película no es un archivo BSV1 válido"
	)
MSG_HASH(
	MSG_MOVIE_FORMAT_DIFFERENT_SERIALIZER_VERSION,
	"El formato de la película parece tener una versión diferente de serializer. Probablemente fallará"
	)
MSG_HASH(
	MSG_MOVIE_PLAYBACK_ENDED,
	"Finalizó la reproducción"
	)
MSG_HASH(
	MSG_MOVIE_RECORD_STOPPED,
	"Deteniendo la grabación"
	)
MSG_HASH(
	MSG_NETPLAY_FAILED,
	"Fallo al iniciar juego en red"
	)
MSG_HASH(
	MSG_NO_CONTENT_STARTING_DUMMY_CORE,
	"No hay contenido, iniciando núcleo vacío"
	)
MSG_HASH(
	MSG_NO_SAVE_STATE_HAS_BEEN_OVERWRITTEN_YET,
	"No hay guardado sobrescrito todavía"
	)
MSG_HASH(
	MSG_NO_STATE_HAS_BEEN_LOADED_YET,
	"No hay guardado cargado todavía"
	)
MSG_HASH(
	MSG_OVERRIDES_ERROR_SAVING,
	"Error guardando anulaciones"
	)
MSG_HASH(
	MSG_OVERRIDES_SAVED_SUCCESSFULLY,
	"Anulaciones guardadas exitosamente"
	)
MSG_HASH(
	MSG_PAUSED,
	"Pausado"
	)
MSG_HASH(
	MSG_PROGRAM,
	"RetroArch"
	)
MSG_HASH(
	MSG_READING_FIRST_DATA_TRACK,
	"Leyendo la primer pista de datos..."
	)
MSG_HASH(
	MSG_RECEIVED,
	"recibido"
	)
MSG_HASH(
	MSG_RECORDING_TERMINATED_DUE_TO_RESIZE,
	"Grabación terminada debido al cambio de tamaño"
	)
MSG_HASH(
	MSG_RECORDING_TO,
	"Grabando en"
	)
MSG_HASH(
	MSG_REDIRECTING_CHEATFILE_TO,
	"Redirigiendo archivo de trucos a"
	)
MSG_HASH(
	MSG_REDIRECTING_SAVEFILE_TO,
	"Redirigiendo archivo de guardado a"
	)
MSG_HASH(
	MSG_REDIRECTING_SAVESTATE_TO,
	"Redirigiendo archivo de guardado rápido a"
	)
MSG_HASH(
	MSG_REMAP_FILE_SAVED_SUCCESSFULLY,
	"Reasignaciones guardadas exitosamente"
	)
MSG_HASH(
	MSG_REMAP_FILE_REMOVED_SUCCESSFULLY,
	"Reasignaciones eliminadas exitosamente"
	)
MSG_HASH(
	MSG_REMOVED_DISK_FROM_TRAY,
	"Quitado el disco de la bandeja"
	)
MSG_HASH(
	MSG_REMOVING_TEMPORARY_CONTENT_FILE,
	"Eliminando el contenido temporal"
	)
MSG_HASH(
	MSG_RESET,
	"Reset"
	)
MSG_HASH(
	MSG_RESTARTING_RECORDING_DUE_TO_DRIVER_REINIT,
	"Reiniciando grabación por reinicio del controlador"
	)
MSG_HASH(
	MSG_RESTORED_OLD_SAVE_STATE,
	"Restaurado antiguo guardado rápido"
	)
MSG_HASH(
	MSG_RESTORING_DEFAULT_SHADER_PRESET_TO,
	"Shaders: restaurado el preset por defecto en"
	)
MSG_HASH(
	MSG_REVERTING_SAVEFILE_DIRECTORY_TO,
	"Revirtiendo la carpeta de guardado a"
	)
MSG_HASH(
	MSG_REVERTING_SAVESTATE_DIRECTORY_TO,
	"Revirtiendo la carpeta de guardado rápido a"
	)
MSG_HASH(
	MSG_REWINDING,
	"Rebobinando"
	)
MSG_HASH(
	MSG_REWIND_INIT,
	"Iniciando buffer de rebobinado de"
	)
MSG_HASH(
	MSG_REWIND_INIT_FAILED,
	"Fallo al iniciar el buffer. El rebobinado se desactivará"
	)
MSG_HASH(
	MSG_REWIND_INIT_FAILED_THREADED_AUDIO,
	"La implementación usa audio por hilos. No se puede usar rebobinado"
	)
MSG_HASH(
	MSG_REWIND_REACHED_END,
	"Fin del buffer de rebobinado"
	)
MSG_HASH(
	MSG_SAVED_NEW_CONFIG_TO,
	"Guardada nueva configuración en"
	)
MSG_HASH(
	MSG_SAVED_STATE_TO_SLOT,
	"Guardado a la ranura #%d"
	)
MSG_HASH(
	MSG_SAVED_STATE_TO_SLOT_AUTO,
	"Guardado #-1 (auto)"
	)
MSG_HASH(
	MSG_SAVED_SUCCESSFULLY_TO,
	"Guardado exitosamente en"
	)
MSG_HASH(
	MSG_SAVING_RAM_TYPE,
	"Guardando RAM"
	)
MSG_HASH(
	MSG_SAVING_STATE,
	"Guardando"
	)
MSG_HASH(
	MSG_SCANNING,
	"Escaneando"
	)
MSG_HASH(
	MSG_SCANNING_OF_DIRECTORY_FINISHED,
	"Escaneo de carpeta finalizado"
	)
MSG_HASH(
	MSG_SENDING_COMMAND,
	"Enviando comando"
	)
MSG_HASH(
	MSG_SEVERAL_PATCHES_ARE_EXPLICITLY_DEFINED,
	"Varios parches están explicitamente definidos, ignorando todos..."
	)
MSG_HASH(
	MSG_SHADER,
	"Shader"
	)
MSG_HASH(
	MSG_SHADER_PRESET_SAVED_SUCCESSFULLY,
	"Shader preset guardado exitosamente"
	)
MSG_HASH(
	MSG_SKIPPING_SRAM_LOAD,
	"Saltando carga de SaveRAM"
	)
MSG_HASH(
	MSG_SLOW_MOTION,
	"Cámara lenta"
	)
MSG_HASH(
	MSG_FAST_FORWARD,
	"Avance rápido"
	)
MSG_HASH(
	MSG_SLOW_MOTION_REWIND,
	"Rebobinado lento"
	)
MSG_HASH(
	MSG_SRAM_WILL_NOT_BE_SAVED,
	"SaveRAM no se guardará"
	)
MSG_HASH(
	MSG_STARTING_MOVIE_PLAYBACK,
	"Iniciando reproducción de película"
	)
MSG_HASH(
	MSG_STARTING_MOVIE_RECORD_TO,
	"Iniciando grabación de película en"
	)
MSG_HASH(
	MSG_STATE_SIZE,
	"Tamaño del guardado"
	)
MSG_HASH(
	MSG_STATE_SLOT,
	"Ranura de guardado"
	)
MSG_HASH(
	MSG_TAKING_SCREENSHOT,
	"Capturando pantalla"
	)
MSG_HASH(
	MSG_TO,
	"en"
	)
MSG_HASH(
	MSG_UNDID_LOAD_STATE,
	"Deshecha la carga"
	)
MSG_HASH(
	MSG_UNDOING_SAVE_STATE,
	"Deshaciendo el guardado"
	)
MSG_HASH(
	MSG_UNKNOWN,
	"Desconocido"
	)
MSG_HASH(
	MSG_UNPAUSED,
	"Despausado"
	)
MSG_HASH(
	MSG_UNRECOGNIZED_COMMAND,
	"Comando no reconocido"
	)
MSG_HASH(
	MSG_USING_CORE_NAME_FOR_NEW_CONFIG,
	"Usando el nombre del núcleo para la nueva configuración"
	)
MSG_HASH(
	MSG_USING_LIBRETRO_DUMMY_CORE_RECORDING_SKIPPED,
	"Usando núcleo vacío. Saltando grabación"
	)
MSG_HASH(
	MSG_VALUE_CONNECT_DEVICE_FROM_A_VALID_PORT,
	"Conecte el dispositivo a un puerto valido"
	)
MSG_HASH(
	MSG_VALUE_DISCONNECTING_DEVICE_FROM_PORT,
	"Desconectando el dispositivo del puerto"
	)
MSG_HASH(
	MSG_VALUE_REBOOTING,
	"Reiniciando.."
	)
MSG_HASH(
	MSG_VALUE_SHUTTING_DOWN,
	"Apagando.."
	)
MSG_HASH(
	MSG_VERSION_OF_LIBRETRO_API,
	"Versión de la API Libretro"
	)
MSG_HASH(
	MSG_VIEWPORT_SIZE_CALCULATION_FAILED,
	"Fallo el calculo de la ventana! Se continuará usando datos en bruto. Probablemente no funcionará bien .."
	)
MSG_HASH(
	MSG_VIRTUAL_DISK_TRAY,
	"Bandeja de discos virtual"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_AUDIO_LATENCY,
	"Latencia de audio deseada en milisegundos. Puede no ser honrada si el controlador no puede proveerla"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_AUDIO_MUTE,
	"Silencia el audio"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_AUDIO_RATE_CONTROL_DELTA,
	"Ayuda a suavizar imperfecciones de timing al sincronizar audio y video. desactivarlo hace casi imposible una sincronía correcta"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CAMERA_ALLOW,
	"Habilitar o deshabilitar el acceso de los núcleos a la cámara"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_LOCATION_ALLOW,
	"Habilitar o deshabilitar al núcleo a usar los servicios de ubicación"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_INPUT_MAX_USERS,
	"Máxima cantidad de usuarios a soportar por RetroArch"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_INPUT_POLL_TYPE_BEHAVIOR,
	"Influencia como el sondeo es hecho dentro de RetroArch. 'Temprano' o 'Tarde' pueden resultar en menor latencia, dependiendo de su configuración"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_INPUT_ALL_USERS_CONTROL_MENU,
	"Permite a cualquier usuario a controlar el menú. Si se desactiva solo podrá hacerlo el usuario 1"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_AUDIO_VOLUME,
	"0 dB es normal, donde no se aplica ganancia"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_AUDIO_WASAPI_EXCLUSIVE_MODE,
	"Permite al controlador WASAPI tomar control exclusivo del disp. de audio. Al deshabilitarlo se usará el modo compartido"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_AUDIO_WASAPI_FLOAT_FORMAT,
	"Usar formato de punto flotante en WASAPI, Su dispositivo debe soportarlo"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_AUDIO_WASAPI_SH_BUFFER_LENGTH,
	"El tamaño del buffer intermedio (en frames) al usar WASAPI en modo compartido"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_AUDIO_SYNC,
	"Sincronizar audio. Recomendado"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_INPUT_AXIS_THRESHOLD,
	"Cuanto debe mover la palanca para ser detectada. Evita movimientos indeseados en los mandos que no vuelven perfectamente al centro"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_INPUT_BIND_TIMEOUT,
	"Cantidad de segundos a esperar hasta la siguiente asignación"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_INPUT_TURBO_PERIOD,
	"Periodo entre pulsación de los botones turbo (en frames)"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_INPUT_DUTY_CYCLE,
	"Cuanto debe durar la pulsación de los botones turbo (en frames)"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_VSYNC,
	"Sincroniza la salida de la placa de video al refresco de la pantalla. Recomendado"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_ALLOW_ROTATE,
	"Permitir a los núcleos rotar la pantalla. Desactivarlo es útil cuando se puede girar el dispositivo manualmente"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_DUMMY_ON_CORE_SHUTDOWN,
	"Activarlo previene que algunos núcleos con función de apagado cierren RetroArch, en lugar de eso se cargará un núcleo vacío"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CHECK_FOR_MISSING_FIRMWARE,
	"Verificar que el firmware necesario este disponible antes de cargar el contenido"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_REFRESH_RATE,
	"Tasa de refresco vertical de su pantalla. Usada para calcular la velocidad de audio. Nota: Se ignorará si 'Video por hilos' esta activado"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_AUDIO_ENABLE,
	"Activar salida de audio"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_AUDIO_MAX_TIMING_SKEW,
	"El máximo cambio en la velocidad de audio. Incrementarlo permite grandes cambios de timing a costa del tono de audio (Ej. Núcleos PAL en pantallas NTSC)"
	)
MSG_HASH(
	MSG_FAILED,
	"Fallo"
	)
MSG_HASH(
	MSG_SUCCEEDED,
	"Éxito"
	)
MSG_HASH(
	MSG_DEVICE_NOT_CONFIGURED,
	"no configurado"
	)
MSG_HASH(
	MSG_DEVICE_NOT_CONFIGURED_FALLBACK,
	"no configurado, usando respaldo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST,
	"Base de datos: Lista cursor"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_DEVELOPER,
	"Base de datos - Filtro : Desarrollador"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_PUBLISHER,
	"Base de datos - Filtro : Distribuidora"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DISABLED,
	"Desactivado"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_ENABLED,
	"Activado"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CONTENT_HISTORY_PATH,
	"Ruta del historial"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_ORIGIN,
	"Base de datos - Filtro : Origen"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_FRANCHISE,
	"Base de datos - Filtro : Franquicia"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_ESRB_RATING,
	"Base de datos - Filtro : ESRB Rating"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_ELSPA_RATING,
	"Base de datos - Filtro : ELSPA Rating"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_PEGI_RATING,
	"Base de datos - Filtro : PEGI Rating"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_CERO_RATING,
	"Base de datos - Filtro : CERO Rating"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_BBFC_RATING,
	"Base de datos - Filtro : BBFC Rating"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_MAX_USERS,
	"Base de datos - Filtro : Máximo de usuarios"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_RELEASEDATE_BY_MONTH,
	"Base de datos - Filtro : Lanzamiento por mes"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_RELEASEDATE_BY_YEAR,
	"Base de datos - Filtro : Lanzamiento por año"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_EDGE_MAGAZINE_ISSUE,
	"Base de datos - Filtro : Numero de la revista Edge"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_EDGE_MAGAZINE_RATING,
	"Base de datos - Filtro : Rating de la revista Edge"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_DATABASE_INFO,
	"Info de base de datos "
	)
MSG_HASH(
	MSG_WIFI_SCAN_COMPLETE,
	"Escaneo Wi-Fi completo"
	)
MSG_HASH(
	MSG_SCANNING_WIRELESS_NETWORKS,
	"Escaneando redes inalambricas.."
	)
MSG_HASH(
	MSG_NETPLAY_LAN_SCAN_COMPLETE,
	"Juego en red escaneo completo"
	)
MSG_HASH(
	MSG_NETPLAY_LAN_SCANNING,
	"Escaneando en busca de anfitriones de juego en red..."
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_PAUSE_NONACTIVE,
	"Pausar gameplay cuando RetroArch no es la ventana activa"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_DISABLE_COMPOSITION,
	"Activar o desactivar composición (Solo Windows)"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_HISTORY_LIST_ENABLE,
	"Activar o desactivar lista de elementos recientes para juegos, imágenes, música, y videos"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CONTENT_HISTORY_SIZE,
	"Limitar el número de entradas en la lista de elementos recientes"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_INPUT_UNIFIED_MENU_CONTROLS,
	"Controles de menú unificados"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_INPUT_UNIFIED_MENU_CONTROLS,
	"Usar los mismos controles para el menú y el juego. Aplica al teclado"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_FONT_ENABLE,
	"Mostrar mensajes en pantalla"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETWORK_USER_REMOTE_ENABLE,
	"Usuario %d Remoto Activado"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_BATTERY_LEVEL_ENABLE,
	"Mostrar nivel de batería"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SELECT_FILE,
	"Seleccionar archivo"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SELECT_FROM_COLLECTION,
	"Seleccionar de la colección"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_FILTER,
	"Filtro"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SCALE,
	"Escalar"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_START_WHEN_LOADED,
	"Juego en red comenzará cuando se cargue el contenido"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_LOAD_CONTENT_MANUALLY,
	"No se encontró el núcleo o contenido, cargue manualmente"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_BROWSE_URL_LIST,
	"Ver URLs"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_BROWSE_URL,
	"Ver URL"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_BROWSE_START,
	"Iniciar"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_BOKEH,
	"Bokeh"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_SNOWFLAKE,
	"Snowflake"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_REFRESH_ROOMS,
	"Actualizar lista de salas"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_ROOM_NICKNAME,
	"Apodo: %s"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_ROOM_NICKNAME_LAN,
	"Apodo (lan): %s"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_COMPAT_CONTENT_FOUND,
	"Contenido compatible encontrado"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_CROP_OVERSCAN,
	"Corta unos pocos pixeles de los bordes de la imagen que normalmente los desarrolladores dejan en blanco o con basura"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_SMOOTH,
	"Aplicar un pequeño desenfoque a la imagen para borrar los bordes de los pixeles. Esta opción tiene muy poco impacto en el rendimiento"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_FILTER,
	"Aplicar un filtro de video con la CPU. Nota: Puede tener un alto coste de rendimiento. Algunos filtros solo funcionan con núcleos que usan 16 o 32bit de color"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CHEEVOS_USERNAME,
	"Nombre de usuario de su cuenta de RetroAchievements"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CHEEVOS_PASSWORD,
	"Contraseña de su cuenta de RetroAchievements"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_NETPLAY_NICKNAME,
	"Ingrese su apodo. Esto sera usado para las sesiones de juego en red"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_POST_FILTER_RECORD,
	"Capturar la imagen con los filtros (no shaders)"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CORE_LIST,
	"Seleccionar que núcleo usar"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_LOAD_CONTENT_LIST,
	"Seleccionar que contenido iniciar"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_NETWORK_INFORMATION,
	"Mostrar interfaces de red e IPs asociadas"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_SYSTEM_INFORMATION,
	"Mostrar información especifica del dispositivo"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_QUIT_RETROARCH,
	"Salir del programa"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_WINDOW_WIDTH,
	"Establece el ancho de la ventana. Al dejarlo en 0 hará que intente ser lo mas grande posible"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_WINDOW_HEIGHT,
	"Establece el alto de la ventana. Al dejarlo en 0 hará que intente ser lo mas grande posible"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_FULLSCREEN_X,
	"Establece el ancho en pantalla completa. Al dejarlo en 0 se usará la resolución del escritorio"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_FULLSCREEN_Y,
	"Establece el alto en pantalla completa. Al dejarlo en 0 se usará la resolución del escritorio"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_MESSAGE_POS_X,
	"Especificar posición sobre eje X para el texto en pantalla"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_MESSAGE_POS_Y,
	"Especificar posición sobre eje Y para el texto en pantalla"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_FONT_SIZE,
	"Especificar el tamaño de letra en puntos"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_INPUT_OVERLAY_HIDE_IN_MENU,
	"Ocultar el overlay en el menú, mostrarlo al salir del menú"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_INPUT_OVERLAY_SHOW_PHYSICAL_INPUTS,
	"Mostrar pulsaciones de teclado/mando en overlay"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_INPUT_OVERLAY_SHOW_PHYSICAL_INPUTS_PORT,
	"Seleccionar el puerto en que el overlay escuchará las pulsaciones"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CONTENT_COLLECTION_LIST,
	"El contenido escaneado aparecerá aquí"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_SCALE_INTEGER,
	"Escalar en múltiplos enteros. El tamaño base dependerá del sistema usado. Si 'Forzar aspecto' no esta activado, X e Y serán escalados individualmente"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_GPU_SCREENSHOT,
	"Capturas de pantalla de GPU con shaders si está disponible"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_ROTATION,
	"Fuerza una cierta rotación de la pantalla. La rotación se añade a la impuesta por el núcleo"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_FORCE_SRGB_DISABLE,
	"Desactiva forzadamente el soporte de FBO sRGB. Para algunos controladores Intel OpenGL en Windows con problemas"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_FULLSCREEN,
	"Puede ser anulado por un argumento en la linea de comandos"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_WINDOWED_FULLSCREEN,
	"Preferir uso de ventana sin bordes a pantalla completa"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_GPU_RECORD,
	"Graba la salida de GPU con shaders si está disponible"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_SAVESTATE_AUTO_INDEX,
	"Al hacer un guardado rápido, el indice es automáticamente incrementado antes de guardar. Al cargar contenido, el indice será el mayor existente"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_BLOCK_SRAM_OVERWRITE,
	"Bloquear el guardado de SaveRAM de ser sobrescrito al cargar guardados rápidos. Puede causar problemas"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_FASTFORWARD_RATIO,
	"La máxima velocidad del avance rápido (Ej: 5.0x para un juego de 60fps = 300 fps). Si es 0 no habrá limite"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_SLOWMOTION_RATIO,
	"Al usar cámara lenta, el contenido se ralentizará el factor especificado"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_REWIND_ENABLE,
	"Habilita el rebobinado. Tendrá un impacto en el rendimiento del juego"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_REWIND_GRANULARITY,
	"Rebobinar un determinado numero de frames, al hacerlo varios a la vez, aumentas la velocidad del rebobinado"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_LIBRETRO_LOG_LEVEL,
	"Nivel de registro para núcleos, si el núcleo emite valores por debajo, serán ignorados"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_PERFCNT_ENABLE,
	"Activa los contadores de rendimiento para RetroArch y núcleos"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_SAVESTATE_AUTO_SAVE,
	"Hacer un guardado rápido al salir de RetroArch. Se cargará automáticamente si 'Cargar guardado rápido automáticamente' esta activado"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_SAVESTATE_AUTO_LOAD,
	"Carga el guardado rápido automático al inicio"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_SAVESTATE_THUMBNAIL_ENABLE,
	"Mostrar miniaturas de los guardados rápidos en el menú"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_AUTOSAVE_INTERVAL,
	"Intervalo en segundos para auto-guardar la memoria no volátil SaveRAM, por defecto desactivado (en 0)"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_INPUT_REMAP_BINDS_ENABLE,
	"Al activarlo anula los controles por defecto y usa los controles personalizados para el núcleo actual"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_INPUT_AUTODETECT_ENABLE,
	"Activar la auto-detección de controles, se intentará configurarlos estilo 'Plug and Play'"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_MENU_INPUT_SWAP_OK_CANCEL,
	"Intercambiar los botones de OK y Cancelar. Desactivado es el estilo Japones, Activado el estilo occidental"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_PAUSE_LIBRETRO,
	"Al desactivarlo el contenido continuará ejecutándose cuando estés en el menú"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_DRIVER,
	"Controlador de video a usar"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_AUDIO_DRIVER,
	"Controlador de audio a usar"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_INPUT_DRIVER,
	"Controlador de entrada a usar. El controlador de video puede forzar uno distinto"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_JOYPAD_DRIVER,
	"Controlador de mando a usar"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_AUDIO_RESAMPLER_DRIVER,
	"Audio resampler a usar"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CAMERA_DRIVER,
	"Controlador de Cámara a usar"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_LOCATION_DRIVER,
	"Controlador de ubicación a usar"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_MENU_DRIVER,
	"Controlador de menú a usar"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_RECORD_DRIVER,
	"Controlador de grabación a usar"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_WIFI_DRIVER,
	"Controlador WiFi a usar"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_NAVIGATION_BROWSER_FILTER_SUPPORTED_EXTENSIONS_ENABLE,
	"Solo mostrar archivos con extensiones conocidas"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_MENU_WALLPAPER,
	"Seleccionar una imagen para usar de fondo en el menú"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_DYNAMIC_WALLPAPER,
	"Cargar una imagen de fondo según el contenido"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_AUDIO_DEVICE,
	"Dispositivo a usar por el controlador de audio. Depende del controlador"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_AUDIO_DSP_PLUGIN,
	"DSP que procesa el audio antes de ser enviado al controlador"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_AUDIO_OUTPUT_RATE,
	"Velocidad de muestreo de la salida de audio"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_OVERLAY_OPACITY,
	"Opacidad de overlay"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_OVERLAY_SCALE,
	"Tamaño de overlay"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_INPUT_OVERLAY_ENABLE,
	"Activar overlay"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_OVERLAY_PRESET,
	"Seleciona un overlay desde el explorador de archivos"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_NETPLAY_IP_ADDRESS,
	"La dirección del servidor a conectar"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_NETPLAY_TCP_UDP_PORT,
	"El puerto del servidor a conectar. Puede ser TCP o UDP"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_NETPLAY_PASSWORD,
	"Contraseña a pedir a los clientes que se conecten al estar en modo servidor"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_NETPLAY_PUBLIC_ANNOUNCE,
	"Permite ser encontrado fácilmente, sino los clientes deberán conectarse manualmente"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_NETPLAY_SPECTATE_PASSWORD,
	"Contraseña a pedir a los espectadores que se conecten al estar en modo servidor"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_NETPLAY_START_AS_SPECTATOR,
	"Si se debe iniciar juego en red en modo espectador"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_NETPLAY_ALLOW_SLAVES,
	"Si se permiten conexiones en modo esclavo. El modo esclavo usa muy poco poder de procesamiento, pero tendrá un impacto significativo en la latencia"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_NETPLAY_REQUIRE_SLAVES,
	"Solo usar modo esclavo. No recomendado excepto en redes muy rápidas con máquinas muy débiles"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_NETPLAY_STATELESS_MODE,
	"Activarlo necesita una red muy rápida, pero se eliminará el jitter al no realizar rebobinados"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_NETPLAY_CHECK_FRAMES,
	"Frecuencia en frames con la que se verificará si el servidor y el cliente están en sincronía"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_NETPLAY_NAT_TRAVERSAL,
	"Cuando se es servidor, intentar escuchar conexiones desde Internet, usando UPnP o tecnologías similares."
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_STDIN_CMD_ENABLE,
	"Activar linea de comandos stdin"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_MOUSE_ENABLE,
	"Activar control con ratón en el menú"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_POINTER_ENABLE,
	"Activar controles táctiles en el menú"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_THUMBNAILS,
	"Tipo de miniaturas a mostrar"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_TIMEDATE_ENABLE,
	"Mostrar el día y hora en el menú"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_BATTERY_LEVEL_ENABLE,
	"Mostrar el nivel de batería actual menú"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_NAVIGATION_WRAPAROUND,
	"Volver al principio cuando llegue al final de la lista tanto sea vertical como horizontal"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_NETPLAY_ENABLE_HOST,
	"Activar juego en red en modo servidor"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_NETPLAY_ENABLE_CLIENT,
	"Activar juego en red en modo cliente"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_NETPLAY_DISCONNECT,
	"Desconecta una sesión activa de juego en red"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_SCAN_DIRECTORY,
	"Escanea una carpeta en busca de archivos compatibles y los añade a la colección"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_SCAN_FILE,
	"Escanea un archivo compatible y lo añade a la colección"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_SWAP_INTERVAL,
	"Configura esto para reducir la tasa de refresco del monitor a la mitad"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_SORT_SAVEFILES_ENABLE,
	"Ordenar archivos de guardado en carpetas nombradas por núcleo"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_SORT_SAVESTATES_ENABLE,
	"Ordenar guardados rápidos en carpetas nombradas por núcleo"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_NETPLAY_REQUEST_DEVICE_I,
	"Pedir jugar con el dispositivo de entrada dado"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CORE_UPDATER_BUILDBOT_URL,
	"URL de la carpeta del actualizador de núcleos en el buildbot Libretro"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_BUILDBOT_ASSETS_URL,
	"URL de la carpeta de recursos en el buildbot Libretro"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CORE_UPDATER_AUTO_EXTRACT_ARCHIVE,
	"Extraer automáticamente los archivos después de descargarlos"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_NETPLAY_REFRESH_ROOMS,
	"Escanear en busca de nuevas salas"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_DELETE_ENTRY,
	"Eliminar esta entrada de la colección"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_INFORMATION,
	"Ver mas información sobre el contenido"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_ADD_TO_FAVORITES,
	"Agregar entrada a sus favoritos"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_ADD_TO_FAVORITES_PLAYLIST,
	"Agregar entrada a sus favoritos"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_RUN,
	"Iniciar el contenido"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_MENU_FILE_BROWSER_SETTINGS,
	"Ajuste las opciones del explorador de archivos"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_AUTO_REMAPS_ENABLE,
	"Activar controles personalizados por defecto al inicio"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_AUTO_OVERRIDES_ENABLE,
	"Activar configuración personalizada por defecto al inicio"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_GAME_SPECIFIC_OPTIONS,
	"Activar configuración de núcleos personalizada por defecto al inicio"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CORE_ENABLE,
	"Muestra el nombre del núcleo actual en el menú"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_DATABASE_MANAGER,
	"Ver bases de datos"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CURSOR_MANAGER,
	"Ver búsquedas previas"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_TAKE_SCREENSHOT,
	"Captura una imagen de la pantalla"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CLOSE_CONTENT,
	"Cierra el contenido actual. Cualquier cambio no guardado se perderá"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_LOAD_STATE,
	"Carga un guardado rápido desde la ranura seleccionada"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_SAVE_STATE,
	"Guarda en la ranura seleccionada"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_RESUME,
	"Reanudar la ejecución del contenido y salir del menú rápido"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_RESUME_CONTENT,
	"Reanudar la ejecución del contenido y salir del menú rápido"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_STATE_SLOT,
	"Cambia la ranura de guardado actual"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_UNDO_LOAD_STATE,
	"Si se cargo un guardado, el contenido volverá al estado previo a la carga"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_UNDO_SAVE_STATE,
	"Si se sobre-escribió un guardado, se volverá al guardado previo"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_ACCOUNTS_RETRO_ACHIEVEMENTS,
	"Servicio de RetroAchievements. Para mas información, visite http://retroachievements.org"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_ACCOUNTS_LIST,
	"Administra las cuentas de usuario"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_INPUT_META_REWIND,
	"Administra las opciones de rebobinado"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_RESTART_CONTENT,
	"Reinicia el contenido desde el principio"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_SAVE_CURRENT_CONFIG_OVERRIDE_CORE,
	"Guarda un archivo de anulación que se aplicará a todo el contenido cargado con este núcleo. Tomará precedencia sobre la configuración principal"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_SAVE_CURRENT_CONFIG_OVERRIDE_GAME,
	"Guarda un archivo de anulación que se aplicará solo a este contenido cargado. Tomará precedencia sobre la configuración principal"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CORE_CHEAT_OPTIONS,
	"Configurar trucos"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_SHADER_OPTIONS,
	"Configurar shaders para mejorar la imagen"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CORE_INPUT_REMAPPING_OPTIONS,
	"Cambia los controles para el contenido cargado actualmente"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CORE_OPTIONS,
	"Cambia las opciones para el contenido cargado actualmente"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_SHOW_ADVANCED_SETTINGS,
	"Mostrar opciones avanzadas (ocultas por defecto)"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_THREADED_DATA_RUNLOOP_ENABLE,
	"Realizar tareas en un hilo separado"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_PLAYLIST_ENTRY_REMOVE,
	"Permitir al usuario eliminar entradas de las colecciones"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_SYSTEM_DIRECTORY,
	"Establece la carpeta de sistema. Los núcleos usan esto para cargar BIOS, configuraciones de sistema, etc."
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_RGUI_BROWSER_DIRECTORY,
	"Establece la carpeta inicial del explorador de archivos"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CONTENT_DIR,
	"Usualmente establecido por desarrolladores que empaquetan aplicaciones libretro/RetroArch para apuntar a los recursos"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_DYNAMIC_WALLPAPERS_DIRECTORY,
	"Carpeta donde se guardan los fondos de pantalla dinámicos que cambian según el contenido"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_THUMBNAILS_DIRECTORY,
	"Carpeta de miniaturas (cajas, etc.)"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_RGUI_CONFIG_DIRECTORY,
	"Establece la ubicación inicial del explorador del menú"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_NETPLAY_INPUT_LATENCY_FRAMES_MIN,
	"El número de frames de entrada a usar para ocultar la latencia de red durante juego en red. Reduce jitter y el uso de CPU, a costa de incrementar el input lag"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_NETPLAY_INPUT_LATENCY_FRAMES_RANGE,
	"El rango de frames de entrada a usar para ocultar la latencia de red durante juego en red. Reduce jitter y el uso de CPU, a costa de incrementar el input lag dentro de un rango"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_DISK_CYCLE_TRAY_STATUS,
	"Continua el ciclo de discos. Si el disco fue insertado, se expulsará sino se insertará"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_DISK_INDEX,
	"Cambiar el indice de disco"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_DISK_OPTIONS,
	"Administrar imágenes de disco"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_DISK_IMAGE_APPEND,
	"Seleccionar una imagen de disco a insertar"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_MENU_ENUM_THROTTLE_FRAMERATE,
	"Limita los FPS en el menú"
	)
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_LAYOUT,
      "Select a different layout for the XMB interface.")
MSG_HASH(
	MENU_ENUM_SUBLABEL_XMB_THEME,
	"Seleccionar un tema de iconos diferente. Los cambios tendrán efecto al reiniciar"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_XMB_SHADOWS_ENABLE,
	"Activar sombra para los iconos. Tendrá un pequeño impacto en el rendimiento"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_MATERIALUI_MENU_COLOR_THEME,
	"Seleccionar un color diferente para el menú"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_MENU_WALLPAPER_OPACITY,
	"Modificar la opacidad de la imagen de fondo"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_XMB_MENU_COLOR_THEME,
	"Seleccionar un color diferente para el menú"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_XMB_RIBBON_ENABLE,
	"Seleccionar un fondo animado. Puede causar problemas de rendimiento dependiendo del efecto, desactivar si el dispositivo no tiene suficiente potencia"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_XMB_FONT,
	"Seleccionar el tipo de letra usado en el menú"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CONTENT_SHOW_FAVORITES,
	"Mostrar la pestaña de favoritos en el menú principal"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CONTENT_SHOW_IMAGES,
	"Mostrar la pestaña de imágenes en el menú principal"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CONTENT_SHOW_MUSIC,
	"Mostrar la pestaña de música en el menú principal"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CONTENT_SHOW_VIDEO,
	"Mostrar la pestaña de video en el menú principal"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CONTENT_SHOW_NETPLAY,
	"Mostrar la pestaña de juego en red en el menú principal"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CONTENT_SHOW_SETTINGS,
	"Mostrar la pestaña de configuración en el menú principal"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CONTENT_SHOW_HISTORY,
	"Mostrar la pestaña de historial en el menú principal"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CONTENT_SHOW_ADD,
	"Mostrar la pestaña de importar contenido en el menú principal"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_RGUI_SHOW_START_SCREEN,
	"Mostrar pantalla de inicio. Esto es desactivado automáticamente después del primer inicio"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_MATERIALUI_MENU_HEADER_OPACITY,
	"Modificar opacidad del encabezado"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_MATERIALUI_MENU_FOOTER_OPACITY,
	"Modificar opacidad del pie de página"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_DPI_OVERRIDE_ENABLE,
	"El menú es escalado dinamicamente. Activar si desea un valor predefinido"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_DPI_OVERRIDE_VALUE,
	"Establecer DPI. NOTA: Debe activar 'Forzar DPI' para que tenga efecto"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CORE_ASSETS_DIRECTORY,
	"Guardar archivos descargados en esta carpeta"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_INPUT_REMAPPING_DIRECTORY,
	"Guardar controles reasignados en esta carpeta"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_LIBRETRO_DIR_PATH,
	"Buscar contenido/núcleos en esta carpeta"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_LIBRETRO_INFO_PATH,
	"Los archivos de información de aplicación y de núcleos se ubican aquí"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_JOYPAD_AUTOCONFIG_DIR,
	"Los archivos de auto-configuración de mandos se guardan aquí"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_PLAYLIST_DIRECTORY,
	"Guardar colecciones en esta carpeta"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CACHE_DIRECTORY,
	"Almacenar archivos temporales aquí"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CURSOR_DIRECTORY,
	"Almacenar búsquedas guardadas aquí"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CONTENT_DATABASE_DIRECTORY,
	"Las bases de datos están aquí"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_ASSETS_DIRECTORY,
	"Carpeta de recursos, donde la interfaz buscará los iconos e imágenes"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_SAVEFILE_DIRECTORY,
	"Carpeta de guardados, si no se establece se guardará en la carpeta del contenido"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_SAVESTATE_DIRECTORY,
	"Carpeta de guardados rápidos, si no se establece se guardará en la carpeta del contenido"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_SCREENSHOT_DIRECTORY,
	"Carpeta donde guardar capturas de pantalla"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_OVERLAY_DIRECTORY,
	"Carpeta de donde cargar overlays"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CHEAT_DATABASE_PATH,
	"Carpeta de donde cargar trucos"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_AUDIO_FILTER_DIR,
	"Carpeta de donde cargar filtros DSP"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_FILTER_DIR,
	"Carpeta de donde cargar filtros basados en CPU"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_SHADER_DIR,
	"Carpeta de donde cargar filtros basados en GPU"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_RECORDING_OUTPUT_DIRECTORY,
	"Carpeta de donde guardar grabaciones"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_RECORDING_CONFIG_DIRECTORY,
	"Carpeta de donde guardar las configuraciones de grabación"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_FONT_PATH,
	"Seleccionar un tipo de fuente diferente para las notificaciones"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_SHADER_APPLY_CHANGES,
	"Los cambios en la configuración del shader tomarán efecto inmediatamente. Usalo al cambiar la cantidad de pasadas, filtrado, etc."
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_SHADER_NUM_PASSES,
	"Cambiar la cantidad de pasadas de shaders. Puedes asignar shaders individualmente a cada pasada y configurar su escalado y filtrado"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET,
	"Cargar un preset de shader. Sera configurado automáticamente"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET_SAVE_AS,
	"Guardar la configuración actual de shaders cono un nuevo preset"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET_SAVE_CORE,
	"Guardar la configuración actual de shaders para este núcleo"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET_SAVE_GAME,
	"Guardar la configuración actual de shaders para este contenido"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_SHADER_PARAMETERS,
	"Modifica el shader directamente. Los cambios no serán guardados en el preset"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET_PARAMETERS,
	"Modifica el preset de shader actualmente usado en el menú"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CHEAT_NUM_PASSES,
	"Cambiar la cantidad de trucos a usar"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CHEAT_APPLY_CHANGES,
	"Los cambios en los trucos tendrán efecto inmediatamente"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CHEAT_FILE_LOAD,
	"Cargar archivo de trucos"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CHEAT_FILE_SAVE_AS,
	"Guardar trucos actuales a un archivo"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CONTENT_SETTINGS,
	"Accede rápidamente a todas las opciones del juego"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CORE_INFORMATION,
	"Ver información pertinente a la aplicación/núcleo"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_ASPECT_RATIO,
	"Valor de punto flotante (ancho / alto), usado si la relación de aspecto es 'Personal'"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_VIEWPORT_CUSTOM_HEIGHT,
	"Alto usada si la relación de aspecto es establecida en 'Personal'"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_VIEWPORT_CUSTOM_WIDTH,
	"Ancho usada si la relación de aspecto es establecida en 'Personal'"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_VIEWPORT_CUSTOM_X,
	"Margen de posición sobre el eje X de la pantalla. Serán ignorados si 'Escalar en múltiplos enteros' es activado, Entonces serán centrados"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_VIDEO_VIEWPORT_CUSTOM_Y,
	"Margen de posición sobre el eje Y de la pantalla. Serán ignorados si 'Escalar en múltiplos enteros' es activado, Entonces serán centrados"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_USE_MITM_SERVER,
	"Usar servidor relé"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_NETPLAY_USE_MITM_SERVER,
	"Enviar conexiones de juego en red a través de otro servidor (man-in-the-middle). Útil si el servidor está detrás de un firewall o tiene problemas NAT/UPnP"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_NETPLAY_MITM_SERVER,
	"Ubicación del servidor relé"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_NETPLAY_MITM_SERVER,
	"Elegir un servidor relé especifico. Las ubicaciones geográficamente cercanas tienden a tener menor latencia"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_ADD_TO_MIXER,
	"Agregar al mezclador"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_ADD_TO_MIXER_AND_PLAY,
	"Add to mixer and play"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_ADD_TO_MIXER_AND_COLLECTION,
	"Agregar al mezclador y colección"
	)
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_MIXER_AND_COLLECTION_AND_PLAY,
      "Add to mixer and play")
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_FILTER_BY_CURRENT_CORE,
	"Filtrar por núcleo actual"
	)
MSG_HASH(
	MSG_AUDIO_MIXER_VOLUME,
	"Volumen del mezclador de audio global"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_AUDIO_MIXER_VOLUME,
	"Volumen global. 0 dB es normal, donde no se aplica ganancia"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_AUDIO_MIXER_VOLUME,
	"Volumen del mezclador de audio (dB)"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_AUDIO_MIXER_MUTE,
	"Silenciar mezclador de audio"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_AUDIO_MIXER_MUTE,
	"Silencia el mezclador de audio"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MENU_SHOW_ONLINE_UPDATER,
	"Mostrar actualizador en linea"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_MENU_SHOW_ONLINE_UPDATER,
	"Mostrar/ocultar la opción de 'Actualizador en línea'"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MENU_VIEWS_SETTINGS,
	"Vistas"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_MENU_VIEWS_SETTINGS,
	"Mostrar/ocultar elementos del menú"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MENU_SHOW_CORE_UPDATER,
	"Mostrar 'Actualizador de núcleos'"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_MENU_SHOW_CORE_UPDATER,
	"Mostrar/ocultar la habilidad de actualizar núcleos y archivos asociados"
	)
MSG_HASH(
	MSG_PREPARING_FOR_CONTENT_SCAN,
	"Preparando para escaneo de contenido..."
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CORE_DELETE,
	"Borrar núcleo"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CORE_DELETE,
	"Eliminar este núcleo del disco"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MENU_FRAMEBUFFER_OPACITY,
	"Opacidad del Framebuffer"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_MENU_FRAMEBUFFER_OPACITY,
	"Modifica la opacidad del framebuffer"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_GOTO_FAVORITES,
	"Favoritos"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_GOTO_FAVORITES,
	"Contenido agregado a 'Favoritos' aparecerá aquí"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_GOTO_MUSIC,
	"Música"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_GOTO_MUSIC,
	"Música que ha sido previamente reproducida aparecerá aquí"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_GOTO_IMAGES,
	"Imagen"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_GOTO_IMAGES,
	"Imágenes previamente vistas aparecerán aquí"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_GOTO_VIDEO,
	"Video"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_GOTO_VIDEO,
	"Videos previamente reproducidos aparecerán aquí"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MATERIALUI_ICONS_ENABLE,
	"Iconos en el menú"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_MATERIALUI_ICONS_ENABLE,
	"Activar/Desactivar los iconos mostrados a la izquierda del menú"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_XMB_MAIN_MENU_ENABLE_SETTINGS,
	"Activar pestaña de opciones"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_SETTINGS_PASSWORD,
	"Establecer contraseña para activar la pestaña de opciones"
	)
MSG_HASH(
	MSG_INPUT_ENABLE_SETTINGS_PASSWORD,
	"Introducir contraseña"
	)
MSG_HASH(
	MSG_INPUT_ENABLE_SETTINGS_PASSWORD_OK,
	"Contraseña correcta"
	)
MSG_HASH(
	MSG_INPUT_ENABLE_SETTINGS_PASSWORD_NOK,
	"Contraseña incorrecta"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_XMB_MAIN_MENU_ENABLE_SETTINGS,
	"Activa la pestaña de opciones. Es necesario reiniciar para que aparezca"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_CONTENT_SHOW_SETTINGS_PASSWORD,
	"Proveer una contraseña al ocultar la pestaña de opciones, hace posible restaurarla desde el menú principal, activando 'Mostrar pestaña de opciones'"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_PLAYLIST_ENTRY_RENAME,
	"Permitir al usuario renombrar entradas en colecciones"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_PLAYLIST_ENTRY_RENAME,
	"Permitir renombrar entradas"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_RENAME_ENTRY,
	"Renombrar el título de esta entrada"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_RENAME_ENTRY,
	"Renombrar"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MENU_SHOW_LOAD_CORE,
	"Mostrar cargar núcleo"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_MENU_SHOW_LOAD_CORE,
	"Mostrar/ocultar la opción de 'Cargar núcleo'"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MENU_SHOW_LOAD_CONTENT,
	"Mostrar cargar contenido"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_MENU_SHOW_LOAD_CONTENT,
	"Mostrar/ocultar la opción de 'Cargar contenido'"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MENU_SHOW_INFORMATION,
	"Mostrar Información"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_MENU_SHOW_INFORMATION,
	"Mostrar/ocultar la opción de 'Información'"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MENU_SHOW_CONFIGURATIONS,
	"Mostrar configuraciones"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_MENU_SHOW_CONFIGURATIONS,
	"Mostrar/ocultar la opción de 'Configuraciones'"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MENU_SHOW_HELP,
	"Mostrar ayuda"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_MENU_SHOW_HELP,
	"Mostrar/ocultar la opción de 'Ayuda'"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MENU_SHOW_QUIT_RETROARCH,
	"Mostrar salir de RetroArch"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_MENU_SHOW_QUIT_RETROARCH,
	"Mostrar/ocultar la opción de 'Salir de RetroArch'"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MENU_SHOW_REBOOT,
	"Mostrar reiniciar"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_MENU_SHOW_REBOOT,
	"Mostrar/ocultar la opción de 'Reiniciar'"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_QUICK_MENU_VIEWS_SETTINGS,
	"Menú rápido"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_QUICK_MENU_VIEWS_SETTINGS,
	"Mostrar/ocultar elementos del menú rápido"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_TAKE_SCREENSHOT,
	"Mostrar captura de pantalla"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_TAKE_SCREENSHOT,
	"Mostrar/ocultar la opción de 'Captura de pantalla'"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_SAVE_LOAD_STATE,
	"Mostrar guardado rápido"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_SAVE_LOAD_STATE,
	"Mostrar/ocultar la opción de 'Guardado rápido'"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_UNDO_SAVE_LOAD_STATE,
	"Mostrar deshacer carga y guardado rápido"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_UNDO_SAVE_LOAD_STATE,
	"Mostrar/ocultar la opción para deshacer la carga y guardado rápido"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_ADD_TO_FAVORITES,
	"Mostrar agregar a favoritos"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_ADD_TO_FAVORITES,
	"Mostrar/ocultar la opción de 'Agregar a favoritos'"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_OPTIONS,
	"Mostrar opciones"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_OPTIONS,
	"Mostrar/ocultar la opción de 'Opciones'"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_CONTROLS,
	"Mostrar Controles"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_CONTROLS,
	"Mostrar/ocultar la opción de 'Controles'"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_CHEATS,
	"Mostrar trucos"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_CHEATS,
	"Mostrar/ocultar la opción de 'Trucos'"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_SHADERS,
	"Mostrar Shaders"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_SHADERS,
	"Mostrar/ocultar la opción de 'Shaders'"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_SAVE_CORE_OVERRIDES,
	"Mostrar anulaciones de núcleo"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_SAVE_CORE_OVERRIDES,
	"Mostrar/ocultar la opción de 'Guardar anulaciones de núcleo'"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_SAVE_GAME_OVERRIDES,
	"Mostrar anulaciones de juego"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_SAVE_GAME_OVERRIDES,
	"Mostrar/ocultar la opción de 'Guardar anulaciones de juego'"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_INFORMATION,
	"Mostrar información"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_INFORMATION,
	"Mostrar/ocultar la opción de 'Información'"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_BGCOLOR_ENABLE,
	"Activar fondo de notificaciones"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_BGCOLOR_RED,
	"Fondo de notif. componente roja"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_BGCOLOR_GREEN,
	"Fondo de notif. componente verde"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_BGCOLOR_BLUE,
	"Fondo de notif. componente azul"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_BGCOLOR_OPACITY,
	"Fondo de notif. opacidad"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MENU_DISABLE_KIOSK_MODE,
	"Desactivar modo kiosco"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_MENU_DISABLE_KIOSK_MODE,
	"Desactiva el modo kiosco. Es necesario reiniciar para completar"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MENU_ENABLE_KIOSK_MODE,
	"Activar modo kiosco"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_MENU_ENABLE_KIOSK_MODE,
	"Protege la configuración ocultándola"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_MENU_KIOSK_MODE_PASSWORD,
	"Establecer contraseña para desactivar modo kiosco"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_MENU_KIOSK_MODE_PASSWORD,
	"Proveer una contraseña al activar el modo kiosco hace posible desactivarlo desde el menú principal, seleccionando 'Desactivar modo kiosco' e introduciendo la contraseña"
	)
MSG_HASH(
	MSG_INPUT_KIOSK_MODE_PASSWORD,
	"Ingresar contraseña"
	)
MSG_HASH(
	MSG_INPUT_KIOSK_MODE_PASSWORD_OK,
	"Contraseña correcta"
	)
MSG_HASH(
	MSG_INPUT_KIOSK_MODE_PASSWORD_NOK,
	"Contraseña incorrecta"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_COLOR_RED,
	"Notificación componente roja"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_COLOR_GREEN,
	"Notificación componente verde"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_COLOR_BLUE,
	"Notificación componente azul"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_FRAMECOUNT_SHOW,
	"Contador de frames junto a FPS"
	)
MSG_HASH(
	MSG_CONFIG_OVERRIDE_LOADED,
	"Anulaciones de configuraciones cargadas"
	)
MSG_HASH(
	MSG_GAME_REMAP_FILE_LOADED,
	"Archivo de reasignaciones de juego cargado"
	)
MSG_HASH(
	MSG_CORE_REMAP_FILE_LOADED,
	"Archivo de reasignaciones de núcleo cargado"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_AUTOMATICALLY_ADD_CONTENT_TO_PLAYLIST,
	"Agregar contenido automáticamente a la lista de reproducción"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_AUTOMATICALLY_ADD_CONTENT_TO_PLAYLIST,
	"Escanea automáticamente el contenido cargado para que aparezca en las listas de reproducción"
	)
MSG_HASH(
	MSG_SCANNING_OF_FILE_FINISHED,
	"Escaneo de archivo finalizado"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_VIDEO_WINDOW_OPACITY,
	"Opacidad de la ventana"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_AUDIO_RESAMPLER_QUALITY,
	 "Calidad del muestreo de audio"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_AUDIO_RESAMPLER_QUALITY,
	"Valores mas bajos favorecen el rendimiento y bajan la latencia a costa de la calidad, incrementar el valor aumentará la calidad a costa del rendimiento y latencia"
	)
MSG_HASH(
	MENU_ENUM_LABEL_VALUE_SHADER_WATCH_FOR_CHANGES,
	"Vigilar cambios en los shader"
	)
MSG_HASH(
	MENU_ENUM_SUBLABEL_SHADER_WATCH_FOR_CHANGES,
	"Auto-aplica los cambios hechos a los archivos shader del disco"
	)
MSG_HASH(MENU_ENUM_LABEL_VALUE_STATISTICS_SHOW,
      "Display Statistics")
MSG_HASH(MENU_ENUM_SUBLABEL_STATISTICS_SHOW,
      "Show onscreen technical statistics.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_RGUI_BORDER_FILLER_ENABLE,
      "Enable border filler")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_RGUI_BORDER_FILLER_THICKNESS_ENABLE,
      "Enable border filler thickness")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_RGUI_BACKGROUND_FILLER_THICKNESS_ENABLE,
      "Enable background filler thickness")
MSG_HASH(MENU_ENUM_SUBLABEL_CRT_SWITCH_RESOLUTION, "For 15 kHz CRT displays only. Attempts to use exact core/game resolution and refresh rate.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CRT_SWITCH_RESOLUTION, "CRT SwitchRes") 
MSG_HASH(MENU_ENUM_SUBLABEL_CRT_SWITCH_RESOLUTION_SUPER, "When CRT SwitchRes is enabled, force ultrawide horizontal resolution to minimize mode switching.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CRT_SWITCH_RESOLUTION_SUPER, "CRT Super Resolution") 
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_REWIND,
      "Show Rewind Settings")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_REWIND,
      "Show/hide the Rewind options.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_LATENCY,
      "Show/hide the Latency options.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_LATENCY,
      "Show Latency Settings")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_OVERLAYS,
      "Show/hide the Overlay options.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_OVERLAYS,
      "Show Overlay Settings")
MSG_HASH(MENU_ENUM_LABEL_VALUE_AUDIO_ENABLE_MENU,
      "Enable menu audio")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_ENABLE_MENU,
      "Enable or disable menu sound.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_AUDIO_MIXER_SETTINGS,
      "Mixer Settings")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_MIXER_SETTINGS,
      "View and/or modify audio mixer settings.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_OVERRIDE_OPTIONS,
      "Configuration Override options")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_OVERRIDE_OPTIONS,
      "Options for overriding the global configuration.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_PLAY,
      "Will start playback of the audio stream. Once finished, it will remove the current audio stream from memory.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_PLAY_LOOPED,
      "Will start playback of the audio stream. Once finished, it will loop and play the track again from the beginning.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_PLAY_SEQUENTIAL,
      "Will start playback of the audio stream. Once finished, it will jump to the next audio stream in sequential order and repeat this behavior. Useful as an album playback mode.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_STOP,
      "This will stop playback of the audio stream, but not remove it from memory. You can start playing it again by selecting 'Play'.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_REMOVE,
      "This will stop playback of the audio stream and remove it entirely from memory.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_VOLUME,
      "Adjust the volume of the audio stream.")
MSG_HASH(MENU_ENUM_SUBLABEL_ADD_TO_MIXER,
      "Add this audio track to an available audio stream slot. If no slots are currently available, it will be ignored.")
MSG_HASH(MENU_ENUM_SUBLABEL_ADD_TO_MIXER_AND_PLAY,
      "Add this audio track to an available audio stream slot and play it. If no slots are currently available, it will be ignored.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_PLAY,
      "Play")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_PLAY_LOOPED,
      "Play (Looped)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_PLAY_SEQUENTIAL,
      "Play (Sequential)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_STOP,
      "Stop")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_REMOVE,
      "Remove")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_VOLUME,
      "Volume")
